# SPDX-FileCopyrightText: 2024 Bujus_Krachus
#
# SPDX-License-Identifier: GPL-3.0-or-later

import bpy


def get_language():
    """Get the current localization translation, defaults to english"""
    # Language will only update when the script is loaded, so no change at runtime possible.
    current_language = bpy.app.translations.locale
    translations = get_translation()
    return translations.get(current_language, translations["en_US"])


def translate(language_translations, searchstring):
    """A safer way to access translations, as each string has en_US fallback"""
    try:
        return language_translations[searchstring]
    except KeyError:
        try:
            # we don't really need those print notifications, just the fallbacks. Either users notice by themselves and complain or they don't.
            # print(f"Web3D: It seems like {searchstring} is not yet translated for your language. Please create a bug report")
            return get_translation()["en_US"][searchstring]
        except Exception as e:
            # print(f"Web3D: An error occurred whilst translating: {e}, please create a bug report")
            return searchstring


def get_translation():
    """Define the translation dictionary for various languages."""
    ################################################# IMPORTANT ########################################################
    # Remember when changing the english value to also either update or remove corresponding entry from the other languages.
    # Otherwise, we will get inconsistencies across the languages (and we don't want that, do we?)
    # Whilst translation is optimal, deletion is fine as well, then english will get used as fallback.
    # English is the default, the other languages are translated using AI, quality of results may vary...
    ################################################# IMPORTANT ########################################################
    return {
        "en_US": {
            "import": "Import X3D/VRML2",
            "export": "Export X3D",
            "file_unit": "File Unit",
            "file_unit_description": "Unit used in the input file",
            "meter": "Meter",
            "meter_description": "Meter is the default unit of VRML (WRL) and X3D files. Most programs assume the objects to be defined in meters as per specification.",
            "decimeter": "Decimeter",
            "decimeter_description": "",
            "centimeter": "Centimeter",
            "centimeter_description": "",
            "milimeter": "Millimeter",
            "milimeter_description": "",
            "inch": "Inch",
            "inch_description": "",
            "custom": "CUSTOM",
            "custom_description": "Use the scale factor provided below",
            "scale": "Scale",
            "scale_description": "Scale value used when 'File Unit' is set to 'CUSTOM'",
            "selection_only": "Selection Only",
            "selection_only_description": "Export only selected objects",
            "visible_only": "Visible Only",
            "visible_only_description": "Export only visible objects",
            "active_collection_only": "Active Collection Only",
            "active_collection_only_description": "Export only objects from the active collection",
            "apply_modifiers": "Apply Modifiers",
            "apply_modifiers_description": "Use transformed mesh data from each object",
            "triangulate": "Triangulate",
            "triangulate_description": "Write quads into 'IndexedTriangleSet'",
            "normals": "Normals",
            "normals_description": "Write normals with geometry",
            "compress": "Compress",
            "compress_description": "Compress the exported file",
            "hierarchy": "Hierarchy",
            "hierarchy_description": "Export parent child relationships",
            "name_decorations": "Name decorations",
            "name_decorations_description": "Add prefixes to the names of exported nodes to indicate their type",
            "h3d_extensions": "H3D Extensions",
            "h3d_extensions_description": "Export shaders for H3D" +
                    ".\nWARNING: This feature is disabled for blender versions higher than 2.79 "
                    "as the needed API method for exporting shaders got removed from blender. "
                    "\nThis feature may get fixed eventually, but no support expected",
            "as_collection": "Import as collection",
            "as_collection_description": "Import the file as a new collection inside the active collection",
            "solidify": "Solidify",
            "solidify_description": "Solidify objects by adding a solify modifier to each of the objects",
            "solidify_value": "Solidify Value",
            "solidify_value_description": "Value used as width for the solidify modifier",
            "path_mode_name" : "Path Mode",
            "path_mode_description" : "Method used to reference paths",
            "relative_mode" : "Relative",
            "relative_mode_description" : "Always write relative paths (where possible)",
            "strip_mode" : "Strip Path",
            "strip_mode_description" : "Filename only",
            "copy_mode"       : "Copy",
            "copy_mode_description"  : "Copy the file to the destination path (or subdirectory)",
            "label_general": "General",
            "label_transform": "Transform",
            "label_mesh": "Mesh",
            "label_include": "Include",
            "label_geometry": "Geometry",
            "label_media": "Media",
            "batch_off": "Off",
            "batch_off_description": "Active scene to file",
            "batch_collection": "Collection",
            "batch_collection_description": "Each collection as a file",
            "batch_object": "Single Object",
            "batch_object_description": "Each object as a file",
            "batch_scene": "Scene",
            "batch_scene_description": "Each scene as a file",
            "batch_dir": "Batch Own Directory",
            "batch_dir_description": "Create a directory for each exported file",
            "batch_object_hierarchy": "Single Object - Keep Relations",
            "batch_object_hierarchy_description": "Each object and it's child object - keeping the relations - as a file",
            "meta_license_CC_BY_4.0": "CC BY 4.0",
            "meta_license_CC_BY-SA_4.0": "CC BY-SA 4.0",
            "meta_license_CC_BY-NC_4.0": "CC BY-NC 4.0",
            "meta_license_CC0_1.0": "CC0 1.0",
            "meta_license_CC_BY-ND_4.0": "CC BY-ND 4.0",
            "meta_license_GPL_v3": "GNU GPL v3",
            "meta_license_GPL_v2": "GNU GPL v2",
            "meta_license_LGPL_v3": "GNU LGPL v3",
            "meta_license_LGPL_v2.1": "GNU LGPL v2.1",
            "meta_license_MIT_License": "MIT License",
            "meta_license_MIT_No_Attribution": "MIT No Attribution",
            "meta_license_Apache_2.0": "Apache 2.0",
            "meta_license_BSD_3": "BSD 3-Clause License",
            "meta_license_BSD_2": "BSD 2-Clause License",
            "meta_license_BSD_1": "BSD 1-Clause License",
            "meta_license_Standard_Royalty-Free": "Standard Royality Free License",
            "meta_license_Extended_Commercial": "Extended Commercial License",
            "meta_license_Public_Domain": "Public Domain",
            "meta_license_Unlicense": "Unlicense",
            "meta_license_NOSA_1.3": "NASA Open Source Agreement",
            "meta_license_Mozilla_2.0": "Mozilla Public License 2.0",
            "meta_license_Pixar": "Pixar Open Source License",
            "meta_license_none": "None",
            "meta_license_none_description": "No license provided",
            "meta_license_custom_description": "(A tailored license for specific business needs) – Grants specific usage rights based on an agreement with the content owner. Specify in the field below",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Attribution 4.0) – Allows free use, modification, and redistribution as long as credit is given; commonly used for open 3D assets and educational content",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Attribution-ShareAlike 4.0) – Similar to CC BY, but requires derivative works to be licensed under the same terms; often used for open-source 3D models and shared design communities",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Attribution-NonCommercial 4.0) – Allows modification and sharing but prohibits commercial use; frequently used for personal projects, research, and non-profit applications",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Public Domain Dedication) – Places the work in the public domain with no restrictions; ideal for freely sharing 3D models in repositories like Sketchfab and Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Attribution-NoDerivatives 4.0) – Allows redistribution with attribution but does not permit modifications; used for official or brand-sensitive 3D content",
            "meta_license_GPL_v3_description": "(General Public License v3) – Requires any derivative work to also be open-source under GPL v3, ensuring freedom for all users",
            "meta_license_GPL_v2_description": "(General Public License v2) – Similar to GPL v3 but does not include the anti-tivoization clause, often used for legacy open-source projects",
            "meta_license_LGPL_v3_description": "(Lesser General Public License v3) – Allows linking proprietary software with LGPL-licensed code while ensuring modifications remain open-source",
            "meta_license_LGPL_v2.1_description": "(Lesser General Public License v2.1) – An older version of LGPL that allows proprietary linking while maintaining free modifications for core libraries",
            "meta_license_MIT_License_description": "(Most common permissive software license, requires attribution) – Allows unrestricted use, modification, and distribution as long as attribution is provided",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Even more permissive than MIT, no attribution required) – Allows unrestricted use, modification, and distribution without requiring credit, useful for simple code snippets and shared utilities",
            "meta_license_Apache_2.0_description": "(Similar to MIT but includes patent protection) – Allows free use, modification, and distribution with credit, plus legal protections against patent claims",
            "meta_license_BSD_3_description": "(Permissive license with limited liability disclaimers) – Similar to MIT but explicitly prohibits using the author's name for promotional purposes",
            "meta_license_BSD_2_description": "(Simplified BSD) (A more permissive variant of BSD-3) – Allows redistribution with minimal restrictions, commonly used in open-source 3D libraries and utilities",
            "meta_license_BSD_1_description": "(Original BSD) (The most permissive BSD variant, also called BSD Zero) – Allows free use and modification with almost no restrictions but often deprecated in favor of BSD-2 or MIT",
            "meta_license_Standard_Royalty-Free_description": "(Typical for stock 3D assets with limited redistribution rights) – Allows personal and commercial use but prohibits resale or sublicensing",
            "meta_license_Extended_Commercial_description": "(More permissive commercial rights, often for enterprise use) – Allows resale, sublicensing, and broader commercial applications, often at a higher cost",
            "meta_license_Public_Domain_description": "(Explicitly places the work in the public domain, no restrictions at all) – Allows unrestricted use, modification, and redistribution, often applied to historical or government data",
            "meta_license_Unlicense_description": "(Alternative to Public Domain, mainly for software) – Completely removes copyright claims, allowing absolute freedom of use",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Allows free use but requires modifications to be shared back) – Used mainly for space-related datasets and scientific research models.",
            "meta_license_Mozilla_2.0_description": "(A middle-ground license between GPL and MIT) – Allows free use and modification, but modifications must be shared under the same license when distributing modified versions",
            "meta_license_Pixar_description": "(Used for Pixar’s open-source projects like OpenSubdiv) – Allows free use and modification with attribution but includes disclaimers limiting liability",
            "meta_license": "License",
            "meta_license_description": "License to use for the exported file. It will get remarked as metadata, however no license text copy will be provided. To specify a custom license set to CUSTOM and enter the license name in the field below",
            "meta_license_custom": "Custom License",
            "meta_reference": "Reference",
            "meta_reference_description": "Provide links to related resources or documentation",
            "meta_keywords": "Keywords",
            "meta_keywords_description": "List keywords for better categorization or searchability",
            "meta_description": "Description",
            "meta_description_description": "Provide a brief description of the scene or model",
            "meta_title": "Title",
            "meta_title_description": "Specify the name of the X3D scene",
            "meta_creator": "Creator",
            "meta_creator_description": "Specify the author or organization that created the file",
            "label_meta_data": "Meta Data",
        },
        "de_DE": {
            "import": "Importiere X3D/VRML2",
            "export": "Exportiere X3D",
            "file_unit": "Dateieinheit",
            "file_unit_description": "In der Eingabedatei verwendete Einheit",
            "meter": "Meter",
            "meter_description": "Meter ist die Standardeinheit für VRML (WRL) und X3D-Dateien. Die meisten Programme gehen davon aus, dass die Objekte in Metern definiert sind.",
            "decimeter": "Dezimeter",
            "decimeter_description": "",
            "centimeter": "Zentimeter",
            "centimeter_description": "",
            "milimeter": "Millimeter",
            "milimeter_description": "",
            "inch": "Zoll",
            "inch_description": "",
            "custom": "BENUTZERDEFINIERT",
            "custom_description": "Verwendet den unten stehenden Skalierungs-Faktor",
            "scale": "Skalierung",
            "scale_description": "Skalierungswert, der verwendet wird, wenn 'Dateieinheit' auf 'BENUTZERDEFINIERT' gesetzt ist",
            "selection_only": "Nur Auswahl",
            "selection_only_description": "Nur ausgewählte Objekte exportieren",
            "visible_only": "Nur sichtbar",
            "visible_only_description": "Nur sichtbare Objekte exportieren",
            "active_collection_only": "Nur aktive Sammlung",
            "active_collection_only_description": "Nur Objekte aus der aktiven Sammlung exportieren",
            "apply_modifiers": "Modifier anwenden",
            "apply_modifiers_description": "Transformierte Mesh-Daten von jedem Objekt verwenden",
            "triangulate": "Triangulieren",
            "triangulate_description": "Quads in 'IndexedTriangleSet' schreiben",
            "normals": "Normalen",
            "normals_description": "Normalen mit Geometrie schreiben",
            "compress": "Komprimieren",
            "compress_description": "Die exportierte Datei komprimieren",
            "hierarchy": "Hierarchie",
            "hierarchy_description": "Eltern-Kind-Beziehungen exportieren",
            "name_decorations": "Namenszusätze",
            "name_decorations_description": "Präfixe zu den Namen der exportierten Knoten hinzufügen, um ihren Typ anzuzeigen",
            "h3d_extensions": "H3D Erweiterungen",
            "h3d_extensions_description": "Shader für H3D exportieren" +
                    ".\nWARNUNG: Diese Funktion ist für Blender-Versionen höher als 2.79 deaktiviert, " +
                    "da die benötigte API-Methode für den Export von Shadern aus Blender entfernt wurde. " +
                    "\nDiese Funktion könnte möglicherweise behoben werden, aber es wird keine Unterstützung erwartet",
            "as_collection": "Als Sammlung importieren",
            "as_collection_description": "Importieren Sie die Datei als neue Sammlung innerhalb der aktiven Sammlung",
            "solidify": "Verfestigen",
            "solidify_description": "Objekte verfestigen, indem jedem Objekt ein Verfestigungsmodifikator hinzugefügt wird",
            "solidify_value": "Verfestigungswert",
            "solidify_value_description": "Wert, der als Breite für den Verfestigungsmodifikator verwendet wird",
            "path_mode_name": "Pfadmodus",
            "path_mode_description": "Methode zur Referenzierung von Pfaden",
            "relative_mode": "Relativ",
            "relative_mode_description": "Immer relative Pfade schreiben (wenn möglich)",
            "strip_mode": "Pfad entfernen",
            "strip_mode_description": "Nur Dateiname",
            "copy_mode": "Kopieren",
            "copy_mode_description": "Kopiere die Datei in den Zielpfad (oder Unterverzeichnis)",
            "label_general": "Allgemein",
            "label_transform": "Transformation",
            "label_mesh": "Mesh",
            "label_include": "Inkludiere",
            "label_geometry": "Geometrie",
            "label_media": "Medien",
            "batch_off": "Aus",
            "batch_off_description": "Aktive Szene in Datei",
            "batch_collection": "Sammlung",
            "batch_collection_description": "Jede Sammlung als Datei",
            "batch_object": "Einzelnes Objekt",
            "batch_object_description": "Jedes Objekt als Datei",
            "batch_scene": "Szene",
            "batch_scene_description": "Jede Szene als Datei",
            "batch_dir": "Eigenes Verzeichnis",
            "batch_dir_description": "Erstelle ein Verzeichnis für jede exportierte Datei",
            "batch_object_hierarchy": "Einzelnes Objekt - Relationen beibehalten",
            "batch_object_hierarchy_description": "Jedes Objekt und seine untergeordneten Objekte - Relationen beibehalten - als Datei",
            "meta_license_none": "Keine",
            "meta_license_none_description": "Keine Lizenz bereitgestellt",
            "meta_license_custom_description": "(Eine maßgeschneiderte Lizenz für spezifische geschäftliche Anforderungen) – Gewährt spezifische Nutzungsrechte basierend auf einer Vereinbarung mit dem Inhaltseigentümer. Im Feld unten angeben",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Attribution 4.0) – Erlaubt freie Nutzung, Modifikation und Weiterverbreitung, solange eine Namensnennung erfolgt; häufig für offene 3D-Assets und Bildungsinhalte verwendet",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Attribution-ShareAlike 4.0) – Ähnlich wie CC BY, erfordert jedoch, dass abgeleitete Werke unter denselben Bedingungen lizenziert werden; oft für Open-Source-3D-Modelle und geteilte Design-Communities genutzt",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Attribution-NonCommercial 4.0) – Erlaubt Modifikation und Weitergabe, verbietet jedoch kommerzielle Nutzung; häufig für persönliche Projekte, Forschung und gemeinnützige Anwendungen genutzt",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Public Domain Dedication) – Stellt das Werk ohne Einschränkungen in die Gemeinfreiheit; ideal für frei geteilte 3D-Modelle in Repositories wie Sketchfab und Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Attribution-NoDerivatives 4.0) – Erlaubt Weiterverbreitung mit Namensnennung, jedoch keine Änderungen; verwendet für offizielle oder markensensible 3D-Inhalte",
            "meta_license_GPL_v3_description": "(General Public License v3) – Erfordert, dass alle abgeleiteten Werke ebenfalls unter GPL v3 lizenziert werden, um die Freiheit aller Nutzer sicherzustellen",
            "meta_license_GPL_v2_description": "(General Public License v2) – Ähnlich wie GPL v3, jedoch ohne die Anti-Tivoization-Klausel, oft für ältere Open-Source-Projekte genutzt",
            "meta_license_LGPL_v3_description": "(Lesser General Public License v3) – Erlaubt die Verknüpfung proprietärer Software mit LGPL-lizenziertem Code, während Änderungen Open Source bleiben müssen",
            "meta_license_LGPL_v2.1_description": "(Lesser General Public License v2.1) – Eine ältere Version der LGPL, die proprietäre Verknüpfung erlaubt, aber freie Modifikationen für Kernbibliotheken beibehält",
            "meta_license_MIT_License_description": "(Die am häufigsten verwendete permissive Softwarelizenz, erfordert Namensnennung) – Erlaubt uneingeschränkte Nutzung, Modifikation und Verbreitung, solange eine Namensnennung erfolgt",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Noch permissiver als MIT, keine Namensnennung erforderlich) – Erlaubt uneingeschränkte Nutzung, Modifikation und Verbreitung ohne Nennung des Autors, nützlich für einfache Codeschnipsel und gemeinsam genutzte Werkzeuge",
            "meta_license_Apache_2.0_description": "(Ähnlich wie MIT, jedoch mit Patentschutz) – Erlaubt freie Nutzung, Modifikation und Verbreitung mit Namensnennung sowie rechtlichen Schutz vor Patentansprüchen",
            "meta_license_BSD_3_description": "(Permissive Lizenz mit begrenzten Haftungsausschlüssen) – Ähnlich wie MIT, verbietet jedoch explizit die Nutzung des Autors für Werbezwecke",
            "meta_license_BSD_2_description": "(Vereinfachte BSD) (Eine permissivere Variante von BSD-3) – Erlaubt Weiterverbreitung mit minimalen Einschränkungen, häufig für Open-Source-3D-Bibliotheken und Werkzeuge genutzt",
            "meta_license_BSD_1_description": "(Original BSD) (Die permissivste BSD-Variante, auch BSD Zero genannt) – Erlaubt freie Nutzung und Modifikation mit fast keinen Einschränkungen, aber oft zugunsten von BSD-2 oder MIT ersetzt",
            "meta_license_Standard_Royalty-Free_description": "(Typisch für Stock-3D-Assets mit eingeschränkten Weiterverbreitungsrechten) – Erlaubt persönliche und kommerzielle Nutzung, verbietet jedoch Wiederverkauf oder Unterlizenzierung",
            "meta_license_Extended_Commercial_description": "(Erweiterte kommerzielle Rechte, oft für Unternehmensnutzung) – Erlaubt Wiederverkauf, Unterlizenzierung und breitere kommerzielle Anwendungen, oft gegen höhere Kosten",
            "meta_license_Public_Domain_description": "(Explizit als gemeinfrei gekennzeichnet, keinerlei Einschränkungen) – Erlaubt uneingeschränkte Nutzung, Modifikation und Weiterverbreitung, oft für historische oder behördliche Daten genutzt",
            "meta_license_Unlicense_description": "(Alternative zur Gemeinfreiheit, hauptsächlich für Software) – Entfernt alle Urheberrechtsansprüche und erlaubt absolute Nutzungsfreiheit",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Erlaubt freie Nutzung, erfordert jedoch, dass Modifikationen zurückgegeben werden) – Wird hauptsächlich für weltraumbezogene Datensätze und wissenschaftliche Forschungsmodelle verwendet",
            "meta_license_Mozilla_2.0_description": "(Ein Mittelweg zwischen GPL und MIT) – Erlaubt freie Nutzung und Modifikation, erfordert jedoch, dass Modifikationen unter derselben Lizenz weitergegeben werden",
            "meta_license_Pixar_description": "(Verwendet für Pixars Open-Source-Projekte wie OpenSubdiv) – Erlaubt freie Nutzung und Modifikation mit Namensnennung, enthält jedoch Haftungsausschlüsse",
            "meta_license": "Lizenz",
            "meta_license_description": "Lizenz für die Nutzung der exportierten Datei. Sie wird als Metadaten hinterlegt, jedoch wird kein Lizenztext bereitgestellt. Um eine benutzerdefinierte Lizenz festzulegen, wählen Sie CUSTOM und geben Sie den Lizenznamen im unteren Feld an",
            "meta_license_custom": "Benutzerdefinierte Lizenz",
            "meta_reference": "Referenz",
            "meta_reference_description": "Geben Sie Links zu verwandten Ressourcen oder Dokumentationen an",
            "meta_keywords": "Schlagwörter",
            "meta_keywords_description": "Liste von Schlüsselwörtern zur besseren Kategorisierung oder Suchbarkeit",
            "meta_description": "Beschreibung",
            "meta_description_description": "Geben Sie eine kurze Beschreibung der Szene oder des Modells an",
            "meta_title": "Titel",
            "meta_title_description": "Geben Sie den Namen der X3D-Szene an",
            "meta_creator": "Ersteller",
            "meta_creator_description": "Geben Sie den Autor oder die Organisation an, die die Datei erstellt hat",
            "label_meta_data": "Metadaten",
        },
        "fr_FR": {
            "import": "Importer X3D/VRML2",
            "export": "Exporter X3D",
            "file_unit": "Unité de fichier",
            "file_unit_description": "Unité utilisée dans le fichier d'entrée",
            "meter": "Mètre",
            "meter_description": "Le mètre est l'unité par défaut des fichiers VRML (WRL) et X3D. La plupart des programmes supposent que les objets sont définis en mètres conformément aux spécifications.",
            "decimeter": "Décimètre",
            "decimeter_description": "",
            "centimeter": "Centimètre",
            "centimeter_description": "",
            "milimeter": "Millimètre",
            "milimeter_description": "",
            "inch": "Pouce",
            "inch_description": "",
            "custom": "PERSONNALISÉ",
            "custom_description": "Utiliser le facteur d'échelle fourni ci-dessous",
            "scale": "Échelle",
            "scale_description": "Valeur de l'échelle utilisée lorsque 'Unité de fichier' est définie sur 'PERSONNALISÉ'",
            "selection_only": "Sélection uniquement",
            "selection_only_description": "Exporter uniquement les objets sélectionnés",
            "visible_only": "Visible seulement",
            "visible_only_description": "Exporter uniquement les objets visibles",
            "active_collection_only": "Collection active seulement",
            "active_collection_only_description": "Exporter uniquement les objets de la collection active",
            "apply_modifiers": "Appliquer les modificateurs",
            "apply_modifiers_description": "Utiliser les données de maillage transformées de chaque objet",
            "triangulate": "Trianguler",
            "triangulate_description": "Convertir les quadrilatères en 'IndexedTriangleSet'",
            "normals": "Normales",
            "normals_description": "Écrire les normales avec la géométrie",
            "compress": "Compresser",
            "compress_description": "Compresser le fichier exporté",
            "hierarchy": "Hiérarchie",
            "hierarchy_description": "Exporter les relations parent-enfant",
            "name_decorations": "Décorations de nom",
            "name_decorations_description": "Ajouter des préfixes aux noms des nœuds exportés pour indiquer leur type",
            "h3d_extensions": "Extensions H3D",
            "h3d_extensions_description": "Exporter les shaders pour H3D" +
                                          ".\nAVERTISSEMENT : Cette fonctionnalité est désactivée pour les versions de blender supérieures à 2.79 " +
                                          "car la méthode API nécessaire pour exporter les shaders a été supprimée de blender. " +
                                          "\nCette fonctionnalité pourrait être corrigée éventuellement, mais aucun support n'est attendu",
            "as_collection": "Importer en tant que collection",
            "as_collection_description": "Importer le fichier en tant que nouvelle collection dans la collection active",
            "solidify": "Solidifier",
            "solidify_description": "Solidifier les objets en ajoutant un modificateur de solidité à chacun des objets",
            "solidify_value": "Valeur de solidité",
            "solidify_value_description": "Valeur utilisée comme largeur pour le modificateur de solidité",
            "path_mode_name": "Mode de chemin",
            "path_mode_description": "Méthode utilisée pour référencer les chemins",
            "relative_mode": "Relatif",
            "relative_mode_description": "Toujours écrire des chemins relatifs (lorsque c'est possible)",
            "strip_mode": "Supprimer le chemin",
            "strip_mode_description": "Nom de fichier uniquement",
            "copy_mode": "Copier",
            "copy_mode_description": "Copier le fichier vers le chemin de destination (ou sous-répertoire)",
            "label_general": "Général",
            "label_transform": "Transformer",
            "label_mesh": "Maillage",
            "label_include": "Inclure",
            "label_geometry": "Géométrie",
            "label_media": "Média",
            "batch_off": "Désactivé",
            "batch_off_description": "Scène active vers fichier",
            "batch_collection": "Collection",
            "batch_collection_description": "Chaque collection en tant que fichier",
            "batch_object": "Objet unique",
            "batch_object_description": "Chaque objet en tant que fichier",
            "batch_scene": "Scène",
            "batch_scene_description": "Chaque scène en tant que fichier",
            "batch_dir": "Répertoire propre",
            "batch_dir_description": "Créer un répertoire pour chaque fichier exporté",
            "batch_object_hierarchy": "Objet unique - Conserver les relations",
            "batch_object_hierarchy_description": "Chaque objet et ses objets enfants - en conservant les relations - en tant que fichier",
            "meta_license_none": "Aucune",
            "meta_license_none_description": "Aucune licence fournie",
            "meta_license_custom_description": "(Une licence personnalisée pour des besoins commerciaux spécifiques) – Accorde des droits d'utilisation spécifiques selon un accord avec le propriétaire du contenu. À spécifier dans le champ ci-dessous",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Attribution 4.0) – Autorise l'utilisation, la modification et la redistribution gratuites à condition d'accorder du crédit ; couramment utilisé pour les ressources 3D ouvertes et le contenu éducatif",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Attribution-Partage dans les Mêmes Conditions 4.0) – Similaire à CC BY, mais exige que les œuvres dérivées soient sous la même licence ; souvent utilisé pour les modèles 3D open-source",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Attribution-NonCommercial 4.0) – Autorise la modification et le partage mais interdit l'utilisation commerciale ; fréquemment utilisé pour les projets personnels, la recherche et les applications à but non lucratif",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Domaine Public) – Place l'œuvre dans le domaine public sans restriction ; idéal pour partager librement des modèles 3D sur Sketchfab et Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Attribution-Pas de Modifications 4.0) – Autorise la redistribution avec attribution mais interdit les modifications ; utilisé pour le contenu 3D officiel ou sensible à la marque",
            "meta_license_GPL_v3_description": "(Licence Publique Générale v3) – Exige que tout travail dérivé soit également open-source sous GPL v3, garantissant la liberté d'utilisation",
            "meta_license_GPL_v2_description": "(Licence Publique Générale v2) – Similaire à GPL v3 mais sans la clause anti-tivoïsation, souvent utilisée pour les anciens projets open-source",
            "meta_license_LGPL_v3_description": "(Licence Publique Générale Limitée v3) – Permet de lier un logiciel propriétaire à du code sous LGPL tout en garantissant que les modifications restent open-source",
            "meta_license_LGPL_v2.1_description": "(Licence Publique Générale Limitée v2.1) – Une version plus ancienne de LGPL permettant la liaison avec des logiciels propriétaires tout en conservant la liberté de modification des bibliothèques essentielles",
            "meta_license_MIT_License_description": "(Licence logicielle permissive la plus courante, attribution requise) – Autorise une utilisation, modification et distribution sans restriction tant que l’attribution est fournie",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Encore plus permissif que MIT, sans attribution requise) – Permet l’utilisation, la modification et la distribution sans obligation de mentionner l’auteur, utile pour des extraits de code et des utilitaires partagés",
            "meta_license_Apache_2.0_description": "(Similaire à MIT mais avec protection des brevets) – Autorise une utilisation, modification et distribution gratuite avec attribution et protection juridique contre les revendications de brevets",
            "meta_license_BSD_3_description": "(Licence permissive avec clauses de responsabilité limitées) – Similaire à MIT mais interdit explicitement l'utilisation du nom de l’auteur à des fins promotionnelles",
            "meta_license_BSD_2_description": "(BSD simplifiée) (Une variante plus permissive de BSD-3) – Autorise la redistribution avec peu de restrictions, souvent utilisée pour les bibliothèques et outils 3D open-source",
            "meta_license_BSD_1_description": "(BSD original) (La variante BSD la plus permissive, également appelée BSD Zero) – Permet une utilisation et une modification libres avec presque aucune restriction, mais souvent remplacée par BSD-2 ou MIT",
            "meta_license_Standard_Royalty-Free_description": "(Typique pour les ressources 3D sous licence libre avec droits de redistribution limités) – Autorise l'utilisation personnelle et commerciale, mais interdit la revente ou la sous-licence",
            "meta_license_Extended_Commercial_description": "(Droits commerciaux plus étendus, souvent destinés aux entreprises) – Permet la revente, la sous-licence et des applications commerciales plus larges, souvent à un coût plus élevé",
            "meta_license_Public_Domain_description": "(Place explicitement l'œuvre dans le domaine public, sans aucune restriction) – Permet une utilisation, modification et redistribution illimitées, souvent appliqué aux données historiques ou gouvernementales",
            "meta_license_Unlicense_description": "(Alternative au domaine public, principalement pour les logiciels) – Supprime toutes les revendications de droits d’auteur, permettant une utilisation totalement libre",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Autorise l'utilisation gratuite mais exige le partage des modifications) – Principalement utilisé pour les ensembles de données spatiales et les modèles de recherche scientifique",
            "meta_license_Mozilla_2.0_description": "(Un compromis entre GPL et MIT) – Autorise une utilisation et modification gratuites, mais les modifications doivent être partagées sous la même licence lorsqu'elles sont redistribuées",
            "meta_license_Pixar_description": "(Utilisé pour les projets open-source de Pixar comme OpenSubdiv) – Autorise une utilisation et modification libres avec attribution, mais inclut des clauses de non-responsabilité",
            "meta_license": "Licence",
            "meta_license_description": "Licence à utiliser pour le fichier exporté. Elle sera enregistrée dans les métadonnées, mais aucun texte de licence ne sera fourni. Pour spécifier une licence personnalisée, sélectionnez CUSTOM et entrez le nom de la licence ci-dessous",
            "meta_license_custom": "Licence personnalisée",
            "meta_reference": "Référence",
            "meta_reference_description": "Fournissez des liens vers des ressources ou documentations associées",
            "meta_keywords": "Mots-clés",
            "meta_keywords_description": "Listez des mots-clés pour une meilleure catégorisation ou recherche",
            "meta_description": "Description",
            "meta_description_description": "Fournissez une brève description de la scène ou du modèle",
            "meta_title": "Titre",
            "meta_title_description": "Spécifiez le nom de la scène X3D",
            "meta_creator": "Créateur",
            "meta_creator_description": "Spécifiez l'auteur ou l'organisation ayant créé le fichier",
            "label_meta_data": "Métadonnées",
        },
        "es_ES": {
            "import": "Importar X3D/VRML2",
            "export": "Exportar X3D",
            "file_unit": "Unidad de archivo",
            "file_unit_description": "Unidad utilizada en el archivo de entrada",
            "meter": "Metro",
            "meter_description": "El metro es la unidad predeterminada de los archivos VRML (WRL) y X3D. La mayoría de los programas asumen que los objetos están definidos en metros según las especificaciones.",
            "decimeter": "Decímetro",
            "decimeter_description": "",
            "centimeter": "Centímetro",
            "centimeter_description": "",
            "milimeter": "Milímetro",
            "milimeter_description": "",
            "inch": "Pulgada",
            "inch_description": "",
            "custom": "PERSONALIZADO",
            "custom_description": "Usar el factor de escala proporcionado a continuación",
            "scale": "Escala",
            "scale_description": "Valor de la escala usado cuando 'Unidad de archivo' está configurada en 'PERSONALIZADO'",
            "selection_only": "Solo selección",
            "selection_only_description": "Exportar solo los objetos seleccionados",
            "visible_only": "Solo visible",
            "visible_only_description": "Exportar solo objetos visibles",
            "active_collection_only": "Solo colección activa",
            "active_collection_only_description": "Exportar solo objetos de la colección activa",
            "apply_modifiers": "Aplicar modificadores",
            "apply_modifiers_description": "Usar los datos de malla transformados de cada objeto",
            "triangulate": "Triangular",
            "triangulate_description": "Escribir los cuadriláteros en 'IndexedTriangleSet'",
            "normals": "Normales",
            "normals_description": "Escribir las normales con la geometría",
            "compress": "Comprimir",
            "compress_description": "Comprimir el archivo exportado",
            "hierarchy": "Jerarquía",
            "hierarchy_description": "Exportar las relaciones padre-hijo",
            "name_decorations": "Decoraciones de nombre",
            "name_decorations_description": "Agregar prefijos a los nombres de los nodos exportados para indicar su tipo",
            "h3d_extensions": "Extensiones H3D",
            "h3d_extensions_description": "Exportar shaders para H3D" +
                                          ".\nADVERTENCIA: Esta función está deshabilitada para versiones de blender superiores a 2.79 " +
                                          "ya que se eliminó el método API necesario para exportar shaders de blender. " +
                                          "\nEsta función podría solucionarse eventualmente, pero no se espera soporte",
            "as_collection": "Importar como colección",
            "as_collection_description": "Importar el archivo como una nueva colección dentro de la colección activa",
            "solidify": "Solidificar",
                "solidify_description": "Solidificar objetos agregando un modificador de solidificación a cada uno de los objetos",
                "solidify_value": "Valor de solidificación",
                "solidify_value_description": "Valor usado como ancho para el modificador de solidificación",
            "path_mode_name": "Modo de ruta",
            "path_mode_description": "Método utilizado para referenciar rutas",
            "relative_mode": "Relativo",
            "relative_mode_description": "Siempre escribir rutas relativas (cuando sea posible)",
            "strip_mode": "Eliminar ruta",
            "strip_mode_description": "Solo nombre de archivo",
            "copy_mode": "Copiar",
            "copy_mode_description": "Copiar el archivo a la ruta de destino (o subdirectorio)",
            "label_general": "General",
            "label_transform": "Transformar",
            "label_mesh": "Malla",
            "label_include": "Incluir",
            "label_geometry": "Geometría",
            "label_media": "Medios",
            "batch_off": "Apagado",
            "batch_off_description": "Escena activa a archivo",
            "batch_collection": "Colección",
            "batch_collection_description": "Cada colección como archivo",
            "batch_object": "Objeto único",
            "batch_object_description": "Cada objeto como archivo",
            "batch_scene": "Escena",
            "batch_scene_description": "Cada escena como archivo",
            "batch_dir": "Directorio propio",
            "batch_dir_description": "Crear un directorio para cada archivo exportado",
            "batch_object_hierarchy": "Objeto único - Mantener relaciones",
            "batch_object_hierarchy_description": "Cada objeto y sus objetos secundarios - manteniendo las relaciones - como archivo",
            "meta_license_none": "Ninguna",
            "meta_license_none_description": "No se ha proporcionado ninguna licencia",
            "meta_license_custom_description": "(Una licencia personalizada para necesidades empresariales específicas) – Otorga derechos de uso específicos basados en un acuerdo con el propietario del contenido. Especifíquelo en el campo siguiente",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Atribución 4.0) – Permite el uso, modificación y redistribución gratuitos siempre que se dé crédito; comúnmente usado para activos 3D abiertos y contenido educativo",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Atribución-CompartirIgual 4.0) – Similar a CC BY, pero requiere que las obras derivadas se licencien bajo los mismos términos; a menudo usado para modelos 3D de código abierto y comunidades de diseño compartido",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Atribución-NoComercial 4.0) – Permite la modificación y el intercambio pero prohíbe el uso comercial; frecuentemente usado para proyectos personales, investigación y aplicaciones sin fines de lucro",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Dedicación al Dominio Público) – Coloca el trabajo en el dominio público sin restricciones; ideal para compartir modelos 3D libremente en repositorios como Sketchfab y Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Atribución-SinDerivadas 4.0) – Permite la redistribución con atribución pero no permite modificaciones; usado para contenido 3D oficial o de marca",
            "meta_license_GPL_v3_description": "(Licencia Pública General v3) – Requiere que cualquier obra derivada también sea de código abierto bajo GPL v3, garantizando la libertad para todos los usuarios",
            "meta_license_GPL_v2_description": "(Licencia Pública General v2) – Similar a GPL v3 pero no incluye la cláusula anti-tivoización, a menudo usada para proyectos de código abierto antiguos",
            "meta_license_LGPL_v3_description": "(Licencia Pública General Reducida v3) – Permite vincular software propietario con código licenciado bajo LGPL asegurando que las modificaciones sigan siendo de código abierto",
            "meta_license_LGPL_v2.1_description": "(Licencia Pública General Reducida v2.1) – Una versión más antigua de LGPL que permite la vinculación propietaria mientras mantiene modificaciones libres para bibliotecas centrales",
            "meta_license_MIT_License_description": "(Licencia de software permisiva más común, requiere atribución) – Permite el uso, modificación y distribución sin restricciones siempre que se proporcione atribución",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Incluso más permisiva que MIT, no requiere atribución) – Permite el uso, modificación y distribución sin restricciones ni necesidad de dar crédito, útil para fragmentos de código simples y utilidades compartidas",
            "meta_license_Apache_2.0_description": "(Similar a MIT pero incluye protección de patentes) – Permite el uso, modificación y distribución gratuitos con crédito, además de protecciones legales contra reclamaciones de patentes",
            "meta_license_BSD_3_description": "(Licencia permisiva con exenciones de responsabilidad limitadas) – Similar a MIT pero prohíbe explícitamente el uso del nombre del autor con fines promocionales",
            "meta_license_BSD_2_description": "(BSD Simplificado) (Una variante más permisiva de BSD-3) – Permite la redistribución con restricciones mínimas, comúnmente usado en bibliotecas y utilidades 3D de código abierto",
            "meta_license_BSD_1_description": "(BSD Original) (La variante más permisiva de BSD, también llamada BSD Cero) – Permite el uso y modificación gratuitos con casi ninguna restricción, pero a menudo está en desuso en favor de BSD-2 o MIT",
            "meta_license_Standard_Royalty-Free_description": "(Típico para activos 3D de stock con derechos de redistribución limitados) – Permite el uso personal y comercial pero prohíbe la reventa o sublicenciamiento",
            "meta_license_Extended_Commercial_description": "(Derechos comerciales más permisivos, a menudo para uso empresarial) – Permite la reventa, sublicenciamiento y aplicaciones comerciales más amplias, generalmente a un costo mayor",
            "meta_license_Public_Domain_description": "(Coloca explícitamente el trabajo en el dominio público, sin restricciones en absoluto) – Permite el uso, modificación y redistribución sin restricciones, a menudo aplicado a datos históricos o gubernamentales",
            "meta_license_Unlicense_description": "(Alternativa al Dominio Público, principalmente para software) – Elimina completamente los reclamos de derechos de autor, permitiendo absoluta libertad de uso",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Permite el uso gratuito pero requiere que las modificaciones se compartan) – Usado principalmente para conjuntos de datos relacionados con el espacio y modelos de investigación científica",
            "meta_license_Mozilla_2.0_description": "(Una licencia intermedia entre GPL y MIT) – Permite el uso y modificación gratuitos, pero las modificaciones deben compartirse bajo la misma licencia al distribuir versiones modificadas",
            "meta_license_Pixar_description": "(Usado para proyectos de código abierto de Pixar como OpenSubdiv) – Permite el uso y modificación gratuitos con atribución, pero incluye cláusulas limitando la responsabilidad",
            "meta_license": "Licencia",
            "meta_license_description": "Licencia de uso para el archivo exportado. Se marcará como metadatos, pero no se proporcionará una copia del texto de la licencia. Para especificar una licencia personalizada, seleccione CUSTOM e ingrese el nombre de la licencia en el campo siguiente",
            "meta_license_custom": "Licencia personalizada",
            "meta_reference": "Referencia",
            "meta_reference_description": "Proporcione enlaces a recursos o documentación relacionados",
            "meta_keywords": "Palabras clave",
            "meta_keywords_description": "Liste palabras clave para una mejor categorización o búsqueda",
            "meta_description": "Descripción",
            "meta_description_description": "Proporcione una breve descripción de la escena o modelo",
            "meta_title": "Título",
            "meta_title_description": "Especifique el nombre de la escena X3D",
            "meta_creator": "Creador",
            "meta_creator_description": "Especifique el autor u organización que creó el archivo",
            "label_meta_data": "Metadatos",
        },
        "it_IT": {
            "import": "Importa X3D/VRML2",
            "export": "Esporta X3D",
            "file_unit": "Unità di file",
            "file_unit_description": "Unità utilizzata nel file di input",
            "meter": "Metro",
            "meter_description": "Il metro è l'unità predefinita dei file VRML (WRL) e X3D. La maggior parte dei programmi presume che gli oggetti siano definiti in metri secondo le specifiche.",
            "decimeter": "Decimetro",
            "decimeter_description": "",
            "centimeter": "Centimetro",
            "centimeter_description": "",
            "milimeter": "Millimetro",
            "milimeter_description": "",
            "inch": "Pollice",
            "inch_description": "",
            "custom": "PERSONALIZZATO",
            "custom_description": "Utilizza il fattore di scala fornito qui sotto",
            "scale": "Scala",
            "scale_description": "Valore di scala utilizzato quando 'Unità di file' è impostata su 'PERSONALIZZATO'",
            "selection_only": "Solo selezione",
            "selection_only_description": "Esporta solo gli oggetti selezionati",
            "visible_only": "Solo visibile",
            "visible_only_description": "Esporta solo oggetti visibili",
            "active_collection_only": "Solo raccolta attiva",
            "active_collection_only_description": "Esporta solo oggetti dalla raccolta attiva",
            "apply_modifiers": "Applica modificatori",
            "apply_modifiers_description": "Utilizzare i dati mesh trasformati da ciascun oggetto",
            "triangulate": "Triangolare",
            "triangulate_description": "Scrivi i quadrilateri in 'IndexedTriangleSet'",
            "normals": "Normali",
            "normals_description": "Scrivi le normali con la geometria",
            "compress": "Comprimi",
            "compress_description": "Comprimi il file esportato",
            "hierarchy": "Gerarchia",
            "hierarchy_description": "Esporta le relazioni padre-figlio",
            "name_decorations": "Decorazioni di nome",
            "name_decorations_description": "Aggiungi prefissi ai nomi dei nodi esportati per indicarne il tipo",
            "h3d_extensions": "Estensioni H3D",
            "h3d_extensions_description": "Esporta shader per H3D" +
                                          ".\nAVVISO: Questa funzione è disabilitata per le versioni di blender superiori alla 2.79 " +
                                          "poiché il metodo API necessario per esportare gli shader è stato rimosso da blender. " +
                                          "\nQuesta funzione potrebbe essere risolta in futuro, ma non è previsto alcun supporto",
            "as_collection": "Importa come collezione",
            "as_collection_description": "Importa il file come una nuova collezione all'interno della collezione attiva",
            "solidify": "Solidificare",
            "solidify_description": "Solidifica gli oggetti aggiungendo un modificatore di solidità a ciascun oggetto",
            "solidify_value": "Valore di solidità",
            "solidify_value_description": "Valore usato come larghezza per il modificatore di solidità",
            "path_mode_name": "Modalità percorso",
            "path_mode_description": "Metodo utilizzato per fare riferimento ai percorsi",
            "relative_mode": "Relativo",
            "relative_mode_description": "Scrivi sempre percorsi relativi (dove possibile)",
            "strip_mode": "Rimuovi percorso",
            "strip_mode_description": "Solo nome file",
            "copy_mode": "Copia",
            "copy_mode_description": "Copia il file nel percorso di destinazione (o sottodirectory)",
            "label_general": "Generale",
            "label_transform": "Trasforma",
            "label_mesh": "Mesh",
            "label_include": "Includi",
            "label_geometry": "Geometria",
            "label_media": "Media",
            "batch_off": "Spento",
            "batch_off_description": "Scena attiva nel file",
            "batch_collection": "Collezione",
            "batch_collection_description": "Ogni collezione come file",
            "batch_object": "Oggetto singolo",
            "batch_object_description": "Ogni oggetto come file",
            "batch_scene": "Scena",
            "batch_scene_description": "Ogni scena come file",
            "batch_dir": "Proprio directory",
            "batch_dir_description": "Crea una directory per ogni file esportato",
            "batch_object_hierarchy": "Oggetto singolo - Mantieni relazioni",
            "batch_object_hierarchy_description": "Ogni oggetto e i suoi oggetti figli - mantenendo le relazioni - come file",
            "meta_license_none": "Nessuna",
            "meta_license_none_description": "Nessuna licenza fornita",
            "meta_license_custom_description": "(Una licenza personalizzata per esigenze aziendali specifiche) – Concede diritti d'uso specifici in base a un accordo con il proprietario del contenuto. Specificare nel campo sottostante",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Attribuzione 4.0) – Consente l'uso, la modifica e la redistribuzione gratuiti purché venga attribuita la paternità; comunemente usata per asset 3D open-source e contenuti educativi",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Attribuzione-Condividi allo stesso modo 4.0) – Simile a CC BY, ma richiede che le opere derivate siano rilasciate con la stessa licenza; spesso usata per modelli 3D open-source e comunità di design condiviso",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Attribuzione-NonCommerciale 4.0) – Consente la modifica e la condivisione ma vieta l'uso commerciale; frequentemente utilizzata per progetti personali, ricerca e applicazioni senza scopo di lucro",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Dedicazione al Pubblico Dominio) – Pone l'opera nel pubblico dominio senza restrizioni; ideale per condividere liberamente modelli 3D in repository come Sketchfab e Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Attribuzione-NessunDerivato 4.0) – Consente la redistribuzione con attribuzione ma non permette modifiche; utilizzata per contenuti 3D ufficiali o legati a un marchio",
            "meta_license_GPL_v3_description": "(Licenza Pubblica Generale v3) – Richiede che qualsiasi opera derivata sia anch'essa open-source sotto GPL v3, garantendo la libertà per tutti gli utenti",
            "meta_license_GPL_v2_description": "(Licenza Pubblica Generale v2) – Simile a GPL v3 ma senza la clausola anti-tivoizzazione, spesso usata per progetti open-source legacy",
            "meta_license_LGPL_v3_description": "(Licenza Pubblica Generale Minore v3) – Consente il collegamento di software proprietario con codice LGPL garantendo che le modifiche rimangano open-source",
            "meta_license_LGPL_v2.1_description": "(Licenza Pubblica Generale Minore v2.1) – Una versione più vecchia della LGPL che consente il collegamento con software proprietario mantenendo libere le modifiche per le librerie di base",
            "meta_license_MIT_License_description": "(Licenza software permissiva più comune, richiede attribuzione) – Consente l'uso, la modifica e la distribuzione senza restrizioni purché venga fornita attribuzione",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Ancora più permissiva della MIT, non richiede attribuzione) – Consente l'uso, la modifica e la distribuzione senza restrizioni né obbligo di credito, utile per semplici frammenti di codice e strumenti condivisi",
            "meta_license_Apache_2.0_description": "(Simile alla MIT ma include protezione dei brevetti) – Consente l'uso, la modifica e la distribuzione gratuiti con attribuzione, oltre a protezioni legali contro rivendicazioni sui brevetti",
            "meta_license_BSD_3_description": "(Licenza permissiva con limitazioni di responsabilità) – Simile alla MIT ma vieta esplicitamente l'uso del nome dell'autore per scopi promozionali",
            "meta_license_BSD_2_description": "(BSD semplificata) (Una variante più permissiva della BSD-3) – Consente la ridistribuzione con restrizioni minime, comunemente usata in librerie e strumenti 3D open-source",
            "meta_license_BSD_1_description": "(BSD originale) (La variante BSD più permissiva, chiamata anche BSD Zero) – Consente l'uso e la modifica liberi con quasi nessuna restrizione, ma spesso deprecata a favore di BSD-2 o MIT",
            "meta_license_Standard_Royalty-Free_description": "(Tipico per asset 3D stock con diritti di redistribuzione limitati) – Consente l'uso personale e commerciale ma vieta la rivendita o la sublicenza",
            "meta_license_Extended_Commercial_description": "(Diritti commerciali più permissivi, spesso per uso aziendale) – Consente la rivendita, la sublicenza e applicazioni commerciali più ampie, spesso a un costo maggiore",
            "meta_license_Public_Domain_description": "(Posiziona esplicitamente l'opera nel pubblico dominio, senza alcuna restrizione) – Consente l'uso, la modifica e la redistribuzione senza restrizioni, spesso applicata a dati storici o governativi",
            "meta_license_Unlicense_description": "(Alternativa al Pubblico Dominio, principalmente per software) – Elimina completamente i diritti d'autore, consentendo una libertà d'uso totale",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Consente l'uso gratuito ma richiede la condivisione delle modifiche) – Utilizzata principalmente per set di dati relativi allo spazio e modelli di ricerca scientifica",
            "meta_license_Mozilla_2.0_description": "(Una licenza intermedia tra GPL e MIT) – Consente l'uso e la modifica gratuiti, ma le modifiche devono essere condivise con la stessa licenza quando vengono distribuite versioni modificate",
            "meta_license_Pixar_description": "(Usata per progetti open-source Pixar come OpenSubdiv) – Consente l'uso e la modifica liberi con attribuzione ma include clausole di limitazione della responsabilità",
            "meta_license": "Licenza",
            "meta_license_description": "Licenza da utilizzare per il file esportato. Verrà annotata nei metadati, ma non verrà fornita una copia del testo della licenza. Per specificare una licenza personalizzata, impostare su CUSTOM e inserire il nome della licenza nel campo sottostante",
            "meta_license_custom": "Licenza personalizzata",
            "meta_reference": "Riferimento",
            "meta_reference_description": "Fornire collegamenti a risorse o documentazione correlata",
            "meta_keywords": "Parole chiave",
            "meta_keywords_description": "Elenca parole chiave per una migliore categorizzazione o ricerca",
            "meta_description": "Descrizione",
            "meta_description_description": "Fornire una breve descrizione della scena o del modello",
            "meta_title": "Titolo",
            "meta_title_description": "Specificare il nome della scena X3D",
            "meta_creator": "Creatore",
            "meta_creator_description": "Specificare l'autore o l'organizzazione che ha creato il file",
            "label_meta_data": "Metadati",
        },
        "ru_RU": {
            "import": "Импорт X3D/VRML2",
            "export": "Экспорт X3D",
            "file_unit": "Единица файла",
            "file_unit_description": "Единица, используемая во входном файле",
            "meter": "Метр",
            "meter_description": "Метр — это единица измерения по умолчанию для файлов VRML (WRL) и X3D. Большинство программ предполагают, что объекты определены в метрах в соответствии с спецификацией.",
            "decimeter": "Дециметр",
            "decimeter_description": "",
            "centimeter": "Сантиметр",
            "centimeter_description": "",
            "milimeter": "Миллиметр",
            "milimeter_description": "",
            "inch": "Дюйм",
            "inch_description": "",
            "custom": "ПОЛЬЗОВАТЕЛЬСКИЙ",
            "custom_description": "Использовать указанный ниже коэффициент масштабирования",
            "scale": "Масштаб",
            "scale_description": "Значение масштаба используется, когда 'Единица файла' установлена на 'ПОЛЬЗОВАТЕЛЬСКИЙ'",
            "selection_only": "Только выбор",
            "selection_only_description": "Экспортировать только выбранные объекты",
            "visible_only": "Только видимое",
            "visible_only_description": "Экспорт только видимых объектов",
            "active_collection_only": "Только активная коллекция",
            "active_collection_only_description": "Экспорт только объектов из активной коллекции",
            "apply_modifiers": "Применить модификаторы",
            "apply_modifiers_description": "Использовать преобразованные данные сетки для каждого объекта",
            "triangulate": "Триангулировать",
            "triangulate_description": "Записать квадраты в 'IndexedTriangleSet'",
            "normals": "Нормали",
            "normals_description": "Записать нормали с геометрией",
            "compress": "Сжать",
            "compress_description": "Сжать экспортированный файл",
            "hierarchy": "Иерархия",
            "hierarchy_description": "Экспортировать отношения родитель-ребенок",
            "name_decorations": "Именные префиксы",
            "name_decorations_description": "Добавить префиксы к именам экспортируемых узлов для указания их типа",
            "h3d_extensions": "Расширения H3D",
            "h3d_extensions_description": "Экспорт шейдеров для H3D" +
                                          ".\nПРЕДУПРЕЖДЕНИЕ: Эта функция отключена для версий Blender выше 2.79, " +
                                          "поскольку необходимый метод API для экспорта шейдеров был удален из Blender. " +
                                          "\nЭта функция может быть исправлена в будущем, но поддержки не ожидается",
            "as_collection": "Импортировать как коллекцию",
            "as_collection_description": "Импортировать файл как новую коллекцию внутри активной коллекции",
            "solidify": "Упрочнить",
                "solidify_description": "Укрепляет объекты, добавляя к каждому объекту модификатор упрочнения",
                "solidify_value": "Значение упрочнения",
                "solidify_value_description": "Значение, используемое в качестве ширины для модификатора упрочнения",
            "path_mode_name": "Режим пути",
            "path_mode_description": "Метод ссылки на пути",
            "relative_mode": "Относительный",
            "relative_mode_description": "Всегда записывать относительные пути (если возможно)",
            "strip_mode": "Удалить путь",
            "strip_mode_description": "Только имя файла",
            "copy_mode": "Копировать",
            "copy_mode_description": "Копировать файл в целевой путь (или подкаталог)",
            "label_general": "Общее",
            "label_transform": "Преобразование",
            "label_mesh": "Сетка",
            "label_include": "Включить",
            "label_geometry": "Геометрия",
            "label_media": "Медиа",
            "batch_off": "Выкл.",
            "batch_off_description": "Активная сцена в файл",
            "batch_collection": "Коллекция",
            "batch_collection_description": "Каждая коллекция в виде файла",
            "batch_object": "Один объект",
            "batch_object_description": "Каждый объект в виде файла",
            "batch_scene": "Сцена",
            "batch_scene_description": "Каждая сцена в виде файла",
            "batch_dir": "Собственная папка",
            "batch_dir_description": "Создать папку для каждого экспортированного файла",
            "batch_object_hierarchy": "Один объект - Сохранение связей",
            "batch_object_hierarchy_description": "Каждый объект и его дочерние объекты - с сохранением связей - в виде файла",
            "meta_license_none": "Отсутствует",
            "meta_license_none_description": "Лицензия не предоставлена",
            "meta_license_custom_description": "(Индивидуальная лицензия для конкретных бизнес-потребностей) – Предоставляет определенные права использования на основе соглашения с владельцем контента. Укажите в поле ниже",
            "meta_license_CC_BY_4.0_description": "(Creative Commons Attribution 4.0) – Позволяет свободное использование, модификацию и распространение при условии указания авторства; часто используется для открытых 3D-ресурсов и образовательного контента",
            "meta_license_CC_BY-SA_4.0_description": "(Creative Commons Attribution-ShareAlike 4.0) – Аналогично CC BY, но требует, чтобы производные работы распространялись на тех же условиях; часто используется для моделей 3D с открытым исходным кодом и совместных дизайнерских сообществ",
            "meta_license_CC_BY-NC_4.0_description": "(Creative Commons Attribution-NonCommercial 4.0) – Позволяет модификацию и распространение, но запрещает коммерческое использование; часто применяется для личных проектов, исследований и некоммерческих целей",
            "meta_license_CC0_1.0_description": "(Creative Commons CC0 1.0 - Передача в общественное достояние) – Полностью освобождает работу от авторских прав без ограничений; идеально подходит для свободного распространения 3D-моделей на платформах типа Sketchfab и Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(Creative Commons Attribution-NoDerivatives 4.0) – Разрешает распространение с указанием авторства, но без изменений; используется для официального или брендированного 3D-контента",
            "meta_license_GPL_v3_description": "(General Public License v3) – Требует, чтобы любые производные работы также оставались с открытым исходным кодом под GPL v3, обеспечивая свободу для всех пользователей",
            "meta_license_GPL_v2_description": "(General Public License v2) – Аналогична GPL v3, но без положения против тиовизации, часто используется для устаревших проектов с открытым исходным кодом",
            "meta_license_LGPL_v3_description": "(Lesser General Public License v3) – Позволяет связывание проприетарного ПО с LGPL-кодом при условии, что модификации остаются с открытым исходным кодом",
            "meta_license_LGPL_v2.1_description": "(Lesser General Public License v2.1) – Более старая версия LGPL, позволяющая связывание с проприетарным кодом, сохраняя открытый доступ к измененным основным библиотекам",
            "meta_license_MIT_License_description": "(Наиболее распространенная свободная лицензия, требует указания авторства) – Позволяет свободное использование, модификацию и распространение при условии указания авторства",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (Более свободная, чем MIT, не требует указания авторства) – Позволяет свободное использование, модификацию и распространение без указания авторства, удобно для небольших фрагментов кода и утилит",
            "meta_license_Apache_2.0_description": "(Аналогична MIT, но включает защиту от патентных претензий) – Позволяет свободное использование, модификацию и распространение с указанием авторства и юридической защитой от патентных исков",
            "meta_license_BSD_3_description": "(Лицензия с ограниченной ответственностью) – Аналогична MIT, но запрещает использование имени автора в рекламных целях",
            "meta_license_BSD_2_description": "(Упрощенная BSD) (Более свободная версия BSD-3) – Позволяет распространение с минимальными ограничениями, широко используется в открытых 3D-библиотеках и утилитах",
            "meta_license_BSD_1_description": "(Оригинальная BSD) (Наиболее свободная версия BSD, также известная как BSD Zero) – Позволяет свободное использование и модификацию практически без ограничений, но часто заменяется BSD-2 или MIT",
            "meta_license_Standard_Royalty-Free_description": "(Типичная лицензия для стоковых 3D-активов с ограниченными правами распространения) – Разрешает личное и коммерческое использование, но запрещает перепродажу или сублицензирование",
            "meta_license_Extended_Commercial_description": "(Более свободные коммерческие права, часто для корпоративного использования) – Разрешает перепродажу, сублицензирование и более широкие коммерческие приложения, обычно за дополнительную плату",
            "meta_license_Public_Domain_description": "(Явно помещает работу в общественное достояние, без ограничений) – Позволяет неограниченное использование, модификацию и распространение, часто применяется к историческим или государственным данным",
            "meta_license_Unlicense_description": "(Альтернатива общественному достоянию, в основном для программного обеспечения) – Полностью снимает авторские права, предоставляя абсолютную свободу использования",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (Позволяет свободное использование, но требует публикации изменений) – Используется в основном для данных, связанных с космосом, и научных моделей",
            "meta_license_Mozilla_2.0_description": "(Лицензия средней свободы между GPL и MIT) – Позволяет свободное использование и модификацию, но требует публикации изменений при распространении модифицированных версий",
            "meta_license_Pixar_description": "(Используется для открытых проектов Pixar, таких как OpenSubdiv) – Позволяет свободное использование и модификацию с указанием авторства, но включает ограничение ответственности",
            "meta_license": "Лицензия",
            "meta_license_description": "Лицензия на использование экспортированного файла. Она будет отмечена в метаданных, но копия текста лицензии предоставлена не будет. Чтобы указать пользовательскую лицензию, выберите CUSTOM и введите название лицензии в поле ниже",
            "meta_license_custom": "Пользовательская лицензия",
            "meta_reference": "Ссылка",
            "meta_reference_description": "Укажите ссылки на связанные ресурсы или документацию",
            "meta_keywords": "Ключевые слова",
            "meta_keywords_description": "Перечислите ключевые слова для лучшей категоризации и поиска",
            "meta_description": "Описание",
            "meta_description_description": "Предоставьте краткое описание сцены или модели",
            "meta_title": "Название",
            "meta_title_description": "Укажите название сцены X3D",
            "meta_creator": "Создатель",
            "meta_creator_description": "Укажите автора или организацию, создавшую файл",
            "label_meta_data": "Метаданные",
        },
        "zh_HANS": {
            "import": "导入 X3D/VRML2",
            "export": "导出 X3D",
            "file_unit": "文件单位",
            "file_unit_description": "输入文件中使用的单位",
            "meter": "米",
            "meter_description": "米是 VRML (WRL) 和 X3D 文件的默认单位。大多数程序假设对象按规范以米为单位定义。",
            "decimeter": "分米",
            "decimeter_description": "",
            "centimeter": "厘米",
            "centimeter_description": "",
            "milimeter": "毫米",
            "milimeter_description": "",
            "inch": "英寸",
            "inch_description": "",
            "custom": "自定义",
            "custom_description": "使用下方提供的比例因子",
            "scale": "比例",
            "scale_description": "当 '文件单位' 设置为 '自定义' 时使用的比例值",
            "selection_only": "仅选择",
            "selection_only_description": "仅导出选定的对象",
            "visible_only": "仅可见",
            "visible_only_description": "仅导出可见对象",
            "active_collection_only": "仅活动集合",
            "active_collection_only_description": "仅导出活动集合中的对象",
            "apply_modifiers": "应用修改器",
            "apply_modifiers_description": "使用每个对象的变换网格数据",
            "triangulate": "三角化",
            "triangulate_description": "将四边形写入 'IndexedTriangleSet'",
            "normals": "法线",
            "normals_description": "将法线与几何体一起写入",
            "compress": "压缩",
            "compress_description": "压缩导出的文件",
            "hierarchy": "层次结构",
            "hierarchy_description": "导出父子关系",
            "name_decorations": "名称装饰",
            "name_decorations_description": "在导出的节点名称中添加前缀以指示其类型",
            "h3d_extensions": "H3D 扩展",
            "h3d_extensions_description": "为 H3D 导出着色器" +
                                          "。\n警告：对于高于 Blender 2.79 的版本，此功能已禁用，" +
                                          "因为导出着色器所需的 API 方法已从 Blender 中删除。" +
                                          "\n此功能可能会在将来修复，但不提供支持",
            "as_collection": "作为集合导入",
            "as_collection_description": "将文件作为一个新的集合导入到活动集合中",
            "solidify": "实体化",
            "solidify_description": "通过为每个对象添加实体化修改器来使对象实体化",
            "solidify_value": "实体化值",
            "solidify_value_description": "用作实体化修改器宽度的值",
            "path_mode_name": "路径模式",
            "path_mode_description": "用于引用路径的方法",
            "relative_mode": "相对路径",
            "relative_mode_description": "始终写入相对路径（如果可能）",
            "strip_mode": "去除路径",
            "strip_mode_description": "仅文件名",
            "copy_mode": "复制",
            "copy_mode_description": "将文件复制到目标路径（或子目录）",
            "label_general": "常规",
            "label_transform": "变换",
            "label_mesh": "网格",
            "label_include": "包括",
            "label_geometry": "几何",
            "label_media": "媒体",
            "batch_off": "关闭",
            "batch_off_description": "活动场景到文件",
            "batch_collection": "集合",
            "batch_collection_description": "每个集合作为一个文件",
            "batch_object": "单个对象",
            "batch_object_description": "每个对象作为一个文件",
            "batch_scene": "场景",
            "batch_scene_description": "每个场景作为一个文件",
            "batch_dir": "批量独立目录",
            "batch_dir_description": "为每个导出的文件创建一个目录",
            "batch_object_hierarchy": "单个对象 - 保持关系",
            "batch_object_hierarchy_description": "每个对象及其子对象 - 保持关系 - 作为文件",
            "meta_license_none": "无",
            "meta_license_none_description": "未提供许可证",
            "meta_license_custom_description": "（针对特定业务需求的定制许可证）– 根据与内容所有者的协议授予特定使用权限。请在下方字段中指定",
            "meta_license_CC_BY_4.0_description": "（知识共享 署名 4.0）– 允许自由使用、修改和再分发，只要注明出处；通常用于开源 3D 资产和教育内容",
            "meta_license_CC_BY-SA_4.0_description": "（知识共享 署名-相同方式共享 4.0）– 类似于 CC BY，但要求衍生作品采用相同许可；常用于开源 3D 模型和共享设计社区",
            "meta_license_CC_BY-NC_4.0_description": "（知识共享 署名-非商业性使用 4.0）– 允许修改和共享，但禁止商业用途；常用于个人项目、研究和非营利应用",
            "meta_license_CC0_1.0_description": "（知识共享 CC0 1.0 - 公共领域贡献）– 将作品置于公共领域，无任何限制；适用于自由分享 3D 模型，如 Sketchfab 和 Thingiverse",
            "meta_license_CC_BY-ND_4.0_description": "（知识共享 署名-禁止演绎 4.0）– 允许再分发并注明出处，但不允许修改；适用于官方或品牌敏感的 3D 内容",
            "meta_license_GPL_v3_description": "（通用公共许可证 v3）– 要求所有衍生作品也必须采用 GPL v3 开源许可，确保所有用户享有自由",
            "meta_license_GPL_v2_description": "（通用公共许可证 v2）– 类似于 GPL v3，但不包含反数字限制条款，常用于旧版开源项目",
            "meta_license_LGPL_v3_description": "（较宽松的通用公共许可证 v3）– 允许专有软件与 LGPL 代码链接，同时确保修改部分保持开源",
            "meta_license_LGPL_v2.1_description": "（较宽松的通用公共许可证 v2.1）– LGPL 的旧版本，允许与专有软件链接，但核心库的修改需保持开源",
            "meta_license_MIT_License_description": "（最常见的宽松软件许可证，要求署名）– 允许无限制使用、修改和分发，只需注明作者",
            "meta_license_MIT_No_Attribution_description": "（MIT-0）(比 MIT 更宽松，不要求署名) – 允许自由使用、修改和分发，不需要注明作者，适用于代码片段和共享工具",
            "meta_license_Apache_2.0_description": "（类似 MIT，但包括专利保护）– 允许自由使用、修改和分发，同时提供专利保护",
            "meta_license_BSD_3_description": "（宽松许可证，包含责任限制）– 类似 MIT，但禁止使用作者姓名进行推广",
            "meta_license_BSD_2_description": "（简化 BSD 许可证）– BSD-3 的更宽松版本，允许最少限制的分发，广泛用于开源 3D 库和工具",
            "meta_license_BSD_1_description": "（原始 BSD 许可证）– 最宽松的 BSD 版本，也称 BSD Zero，允许几乎无限制的使用和修改，但通常被 BSD-2 或 MIT 取代",
            "meta_license_Standard_Royalty-Free_description": "（常用于库存 3D 资产，有限制的再分发权利）– 允许个人和商业使用，但禁止转售或再许可",
            "meta_license_Extended_Commercial_description": "（更广泛的商业使用权限，通常适用于企业）– 允许转售、再许可和更广泛的商业应用，通常需要更高费用",
            "meta_license_Public_Domain_description": "（明确将作品置于公共领域，无任何限制）– 允许自由使用、修改和再分发，通常适用于历史或政府数据",
            "meta_license_Unlicense_description": "（公共领域的替代方案，主要用于软件）– 完全取消版权声明，允许绝对自由使用",
            "meta_license_NOSA_1.3_description": "（NOSA 1.3）(允许自由使用，但要求共享修改内容) – 主要用于与太空相关的数据集和科学研究模型",
            "meta_license_Mozilla_2.0_description": "（介于 GPL 和 MIT 之间的中间许可证）– 允许自由使用和修改，但修改后的版本需采用相同许可证发布",
            "meta_license_Pixar_description": "（用于 Pixar 的开源项目，如 OpenSubdiv）– 允许自由使用和修改，并要求署名，但包含责任限制",
            "meta_license": "许可证",
            "meta_license_description": "用于导出文件的许可证。它将被记录在元数据中，但不会提供许可证文本副本。要指定自定义许可证，请选择 CUSTOM 并在下方输入许可证名称",
            "meta_license_custom": "自定义许可证",
            "meta_reference": "参考资料",
            "meta_reference_description": "提供相关资源或文档的链接",
            "meta_keywords": "关键词",
            "meta_keywords_description": "列出关键词，以便更好地分类和搜索",
            "meta_description": "描述",
            "meta_description_description": "提供该场景或模型的简要描述",
            "meta_title": "标题",
            "meta_title_description": "指定 X3D 场景的名称",
            "meta_creator": "创作者",
            "meta_creator_description": "指定创建该文件的作者或组织",
            "label_meta_data": "元数据",
        },
        "ja_JP": {
            "import": "インポート X3D/VRML2",
            "export": "エクスポート X3D",
            "file_unit": "ファイル単位",
            "file_unit_description": "入力ファイルで使用される単位",
            "meter": "メートル",
            "meter_description": "メートルは VRML (WRL) および X3D ファイルのデフォルト単位です。ほとんどのプログラムは、オブジェクトが仕様に従ってメートルで定義されていると仮定します。",
            "decimeter": "デシメートル",
            "decimeter_description": "",
            "centimeter": "センチメートル",
            "centimeter_description": "",
            "milimeter": "ミリメートル",
            "milimeter_description": "",
            "inch": "インチ",
            "inch_description": "",
            "custom": "カスタム",
            "custom_description": "以下で提供されているスケール係数を使用",
            "scale": "スケール",
            "scale_description": "'ファイル単位' が 'カスタム' に設定されている場合に使用されるスケール値",
            "selection_only": "選択のみ",
            "selection_only_description": "選択されたオブジェクトのみをエクスポート",
            "visible_only": "表示中のみ",
            "visible_only_description": "表示中のオブジェクトのみをエクスポート",
            "active_collection_only": "アクティブコレクションのみ",
            "active_collection_only_description": "アクティブなコレクション内のオブジェクトのみをエクスポート",
            "apply_modifiers": "モディファイアを適用",
            "apply_modifiers_description": "各オブジェクトの変換されたメッシュデータを使用",
            "triangulate": "三角形化",
            "triangulate_description": "四角形を 'IndexedTriangleSet' に書き込む",
            "normals": "法線",
            "normals_description": "ジオメトリに法線を書き込む",
            "compress": "圧縮",
            "compress_description": "エクスポートされたファイルを圧縮",
            "hierarchy": "階層構造",
            "hierarchy_description": "親子関係をエクスポート",
            "name_decorations": "名前装飾",
            "name_decorations_description": "エクスポートされたノードの名前にプレフィックスを追加してタイプを示す",
            "h3d_extensions": "H3D 拡張機能",
            "h3d_extensions_description": "H3D のシェーダーをエクスポート" +
                                          ".\n警告：この機能は Blender 2.79 より上のバージョンでは無効になっています。" +
                                          "シェーダーをエクスポートするために必要な API メソッドが Blender から削除されたためです。" +
                                          "\nこの機能は将来的に修正される可能性がありますが、サポートは期待されていません。",
            "as_collection": "コレクションとしてインポート",
            "as_collection_description": "ファイルをアクティブなコレクション内に新しいコレクションとしてインポートします",
            "solidify": "ソリディファイ",
            "solidify_description": "各オブジェクトにソリディファイモディファイアを追加してオブジェクトをソリディファイする",
            "solidify_value": "ソリディファイ値",
            "solidify_value_description": "ソリディファイモディファイアの幅として使用する値",
            "path_mode_name": "パスモード",
            "path_mode_description": "パスを参照する方法",
            "relative_mode": "相対パス",
            "relative_mode_description": "常に相対パスを記述する（可能な場合）",
            "strip_mode": "パスを削除",
            "strip_mode_description": "ファイル名のみ",
            "copy_mode": "コピー",
            "copy_mode_description": "ファイルを宛先パス（またはサブディレクトリ）にコピーする",
            "label_general": "一般",
            "label_transform": "変換",
            "label_mesh": "メッシュ",
            "label_include": "含める",
            "label_geometry": "ジオメトリ",
            "label_media": "メディア",
            "batch_off": "オフ",
            "batch_off_description": "アクティブなシーンをファイルへ",
            "batch_collection": "コレクション",
            "batch_collection_description": "各コレクションをファイルに",
            "batch_object": "単一オブジェクト",
            "batch_object_description": "各オブジェクトをファイルに",
            "batch_scene": "シーン",
            "batch_scene_description": "各シーンをファイルに",
            "batch_dir": "専用ディレクトリ",
            "batch_dir_description": "各エクスポートファイルのディレクトリを作成",
            "batch_object_hierarchy": "単一オブジェクト - 関係を維持",
            "batch_object_hierarchy_description": "各オブジェクトとその子オブジェクト - 関係を維持 - ファイルとして",
            "meta_license_none": "なし",
            "meta_license_none_description": "ライセンスが提供されていません",
            "meta_license_custom_description": "（特定のビジネスニーズに対応したカスタムライセンス）– コンテンツ所有者との合意に基づいて特定の使用権を付与。下記のフィールドに指定してください",
            "meta_license_CC_BY_4.0_description": "（クリエイティブ・コモンズ 表示 4.0）– クレジットを表記すれば、自由に使用、改変、再配布が可能。オープンな 3D アセットや教育コンテンツによく利用される",
            "meta_license_CC_BY-SA_4.0_description": "（クリエイティブ・コモンズ 表示-継承 4.0）– CC BY と似ているが、派生作品も同じライセンスで公開する必要がある。オープンソースの 3D モデルや共有デザインコミュニティでよく使用される",
            "meta_license_CC_BY-NC_4.0_description": "（クリエイティブ・コモンズ 表示-非営利 4.0）– 改変と共有は可能だが、商業利用は禁止。個人プロジェクト、研究、非営利目的での利用が一般的",
            "meta_license_CC0_1.0_description": "（クリエイティブ・コモンズ CC0 1.0 - パブリックドメイン貢献）– 作品を完全にパブリックドメインにし、制限なしで自由に使用可能。Sketchfab や Thingiverse などの 3D モデル共有に最適",
            "meta_license_CC_BY-ND_4.0_description": "（クリエイティブ・コモンズ 表示-改変禁止 4.0）– クレジットを表記すれば再配布可能だが、改変は禁止。公式コンテンツやブランド管理が必要な 3D コンテンツに適用",
            "meta_license_GPL_v3_description": "（GNU 一般公衆利用許諾契約書 v3）– 派生作品も GPL v3 でオープンソースにすることを義務付け、すべてのユーザーに自由を保証",
            "meta_license_GPL_v2_description": "（GNU 一般公衆利用許諾契約書 v2）– GPL v3 に似ているが、アンチ・ティボ化条項が含まれない。レガシーなオープンソースプロジェクトで使用されることが多い",
            "meta_license_LGPL_v3_description": "（GNU 劣等一般公衆利用許諾契約書 v3）– LGPL ライセンスのコードとプロプライエタリソフトウェアのリンクを許可しながら、改変部分をオープンソースに保つことを義務付ける",
            "meta_license_LGPL_v2.1_description": "（GNU 劣等一般公衆利用許諾契約書 v2.1）– LGPL の旧バージョンで、プロプライエタリソフトウェアとのリンクを許可しつつ、コアライブラリの改変部分はオープンソースにする必要がある",
            "meta_license_MIT_License_description": "（最も一般的な寛容なソフトウェアライセンス。クレジットの表記が必要）– クレジットを表記すれば、自由に使用、改変、再配布が可能",
            "meta_license_MIT_No_Attribution_description": "（MIT-0）(MIT よりもさらに寛容で、クレジット表記不要) – 自由に使用、改変、再配布可能。コードスニペットや共有ユーティリティに適している",
            "meta_license_Apache_2.0_description": "（MIT に似ているが、特許保護を含む）– クレジットを表記すれば自由に使用、改変、再配布が可能であり、特許訴訟からの保護も提供",
            "meta_license_BSD_3_description": "（責任制限がある寛容なライセンス）– MIT に似ているが、作者の名前をプロモーション目的で使用することを明示的に禁止",
            "meta_license_BSD_2_description": "（簡略化 BSD ライセンス）– BSD-3 よりも寛容で、最低限の制限で再配布が可能。オープンソースの 3D ライブラリやツールによく使用される",
            "meta_license_BSD_1_description": "（オリジナル BSD ライセンス）– 最も寛容な BSD バリアントで、ほぼ制限なく自由に使用・改変が可能。ただし、BSD-2 や MIT の方が一般的に採用されている",
            "meta_license_Standard_Royalty-Free_description": "（ストック 3D アセット向けの一般的なライセンスで、限定的な再配布権がある）– 個人および商業利用が可能だが、再販やサブライセンスは禁止",
            "meta_license_Extended_Commercial_description": "（より寛容な商業利用権。企業向けライセンスとして利用されることが多い）– 再販、サブライセンス、より広範な商業利用が可能。通常、追加費用がかかる",
            "meta_license_Public_Domain_description": "（作品を明示的にパブリックドメインにする。制限なし）– 自由に使用、改変、再配布が可能。歴史的データや政府データに適用されることが多い",
            "meta_license_Unlicense_description": "（ソフトウェア向けのパブリックドメイン代替）– 著作権を完全に撤廃し、あらゆる用途に自由に使用できる",
            "meta_license_NOSA_1.3_description": "（NOSA 1.3）（自由に使用可能だが、改変内容の共有を義務付ける）– 主に宇宙関連のデータセットや科学研究モデルで使用",
            "meta_license_Mozilla_2.0_description": "（GPL と MIT の中間的なライセンス）– 自由に使用・改変できるが、改変版の配布時には同じライセンスを適用する必要がある",
            "meta_license_Pixar_description": "（Pixar のオープンソースプロジェクト（OpenSubdiv など）で使用）– クレジット表記があれば自由に使用・改変可能。ただし、責任制限の免責条項を含む",
            "meta_license": "ライセンス",
            "meta_license_description": "エクスポートされたファイルに適用するライセンス。メタデータとして記録されるが、ライセンステキストのコピーは提供されない。カスタムライセンスを指定する場合は、CUSTOM を選択し、下記のフィールドにライセンス名を入力してください",
            "meta_license_custom": "カスタムライセンス",
            "meta_reference": "参考情報",
            "meta_reference_description": "関連リソースやドキュメントへのリンクを提供",
            "meta_keywords": "キーワード",
            "meta_keywords_description": "カテゴリ分けや検索性を向上させるためのキーワードを入力",
            "meta_description": "説明",
            "meta_description_description": "シーンやモデルの簡単な説明を提供",
            "meta_title": "タイトル",
            "meta_title_description": "X3D シーンの名前を指定",
            "meta_creator": "作成者",
            "meta_creator_description": "このファイルを作成した作者または組織を指定",
            "label_meta_data": "メタデータ",
        },
        "hi_IN": {
            "import": "आयात X3D/VRML2",
            "export": "निर्यात X3D",
            "file_unit": "फ़ाइल इकाई",
            "file_unit_description": "इनपुट फ़ाइल में उपयोग की गई इकाई",
            "meter": "मीटर",
            "meter_description": "मीटर VRML (WRL) और X3D फ़ाइलों की डिफ़ॉल्ट इकाई है। अधिकांश प्रोग्राम मानते हैं कि वस्तुओं को निर्दिष्ट अनुसार मीटर में परिभाषित किया गया है।",
            "decimeter": "डेसीमीटर",
            "decimeter_description": "",
            "centimeter": "सेंटीमीटर",
            "centimeter_description": "",
            "milimeter": "मिलीमीटर",
            "milimeter_description": "",
            "inch": "इंच",
            "inch_description": "",
            "custom": "कस्टम",
            "custom_description": "नीचे दिए गए पैमाने का कारक उपयोग करें",
            "scale": "स्केल",
            "scale_description": "'फ़ाइल इकाई' को 'कस्टम' पर सेट किए जाने पर उपयोग किया गया स्केल मान",
            "selection_only": "केवल चयन",
            "selection_only_description": "केवल चयनित वस्तुओं को निर्यात करें",
            "visible_only": "केवल दृश्य",
            "visible_only_description": "केवल दृश्यमान वस्तुएँ निर्यात करें",
            "active_collection_only": "केवल सक्रिय संग्रह",
            "active_collection_only_description": "केवल सक्रिय संग्रह की वस्तुओं को निर्यात करें",
            "apply_modifiers": "मॉडिफ़ायर लागू करें",
            "apply_modifiers_description": "प्रत्येक वस्तु से रूपांतरित मेश डेटा का उपयोग करें",
            "triangulate": "त्रिकोणित करें",
            "triangulate_description": "'IndexedTriangleSet' में चतुर्भुज लिखें",
            "normals": "नॉर्मल",
            "normals_description": "ज्यामिति के साथ नॉर्मल लिखें",
            "compress": "संकुचित करें",
            "compress_description": "निर्यात की गई फ़ाइल को संपीड़ित करें",
            "hierarchy": "अनुक्रम",
            "hierarchy_description": "मूल्य और बाल संबंध निर्यात करें",
            "name_decorations": "नाम सजावट",
            "name_decorations_description": "निर्यात किए गए नोड्स के नामों में उनके प्रकार को इंगित करने के लिए उपसर्ग जोड़ें",
            "h3d_extensions": "H3D एक्सटेंशन",
            "h3d_extensions_description": "H3D के लिए शेडर्स निर्यात करें" +
                                          ".\nचेतावनी: यह सुविधा Blender संस्करण 2.79 से अधिक के लिए अक्षम है, " +
                                          "क्योंकि शेडर्स के निर्यात के लिए आवश्यक API विधि Blender से हटा दी गई है।" +
                                          "\nयह सुविधा भविष्य में ठीक हो सकती है, लेकिन कोई समर्थन अपेक्षित नहीं है",
            "as_collection": "संग्रह के रूप में आयात करें",
            "as_collection_description": "सक्रिय संग्रह के भीतर फ़ाइल को एक नए संग्रह के रूप में आयात करें",
            "solidify": "ठोस बनाएं",
                "solidify_description": "प्रत्येक वस्तु में ठोस संशोधक जोड़कर वस्तुओं को ठोस बनाएं",
                "solidify_value": "ठोस मान",
                "solidify_value_description": "ठोस संशोधक की चौड़ाई के रूप में प्रयुक्त मान",
            "path_mode_name": "पथ मोड",
            "path_mode_description": "पथ संदर्भित करने की विधि",
            "relative_mode": "सापेक्ष",
            "relative_mode_description": "हमेशा सापेक्ष पथ लिखें (जहां संभव हो)",
            "strip_mode": "पथ हटाएं",
            "strip_mode_description": "केवल फ़ाइल नाम",
            "copy_mode": "कॉपी",
            "copy_mode_description": "फ़ाइल को गंतव्य पथ (या उपनिर्देशिका) में कॉपी करें",
            "label_general": "सामान्य",
            "label_transform": "परिवर्तन",
            "label_mesh": "जाल",
            "label_include": "शामिल करें",
            "label_geometry": "ज्यामिति",
            "label_media": "मीडिया",
            "batch_off": "बंद",
            "batch_off_description": "सक्रिय दृश्य को फ़ाइल में",
            "batch_collection": "संग्रह",
            "batch_collection_description": "प्रत्येक संग्रह को एक फ़ाइल के रूप में",
            "batch_object": "एकल वस्तु",
            "batch_object_description": "प्रत्येक वस्तु को एक फ़ाइल के रूप में",
            "batch_scene": "दृश्य",
            "batch_scene_description": "प्रत्येक दृश्य को एक फ़ाइल के रूप में",
            "batch_dir": "स्वयं का निर्देशिका",
            "batch_dir_description": "प्रत्येक निर्यातित फ़ाइल के लिए एक निर्देशिका बनाएं",
            "batch_object_hierarchy": "एकल वस्तु - संबंध बनाए रखें",
            "batch_object_hierarchy_description": "प्रत्येक वस्तु और इसकी बाल वस्तुएं - संबंध बनाए रखते हुए - एक फ़ाइल के रूप में",
            "meta_license_none": "कोई नहीं",
            "meta_license_none_description": "कोई लाइसेंस प्रदान नहीं किया गया",
            "meta_license_custom_description": "(विशिष्ट व्यावसायिक आवश्यकताओं के लिए एक अनुकूलित लाइसेंस) – सामग्री स्वामी के साथ समझौते के आधार पर विशिष्ट उपयोग अधिकार प्रदान करता है। कृपया नीचे दिए गए फ़ील्ड में निर्दिष्ट करें",
            "meta_license_CC_BY_4.0_description": "(क्रिएटिव कॉमन्स एट्रिब्यूशन 4.0) – क्रेडिट दिए जाने पर स्वतंत्र उपयोग, संशोधन और पुनर्वितरण की अनुमति देता है; आमतौर पर खुले 3D एसेट्स और शैक्षिक सामग्री के लिए उपयोग किया जाता है",
            "meta_license_CC_BY-SA_4.0_description": "(क्रिएटिव कॉमन्स एट्रिब्यूशन-शेयरअलाइक 4.0) – CC BY के समान, लेकिन व्युत्पन्न कार्यों को समान शर्तों के तहत लाइसेंस प्राप्त करना आवश्यक होता है; आमतौर पर ओपन-सोर्स 3D मॉडल और साझा डिज़ाइन समुदायों के लिए प्रयुक्त होता है",
            "meta_license_CC_BY-NC_4.0_description": "(क्रिएटिव कॉमन्स एट्रिब्यूशन-नॉनकमर्शियल 4.0) – संशोधन और साझा करने की अनुमति देता है लेकिन व्यावसायिक उपयोग निषिद्ध है; व्यक्तिगत परियोजनाओं, शोध, और गैर-लाभकारी अनुप्रयोगों के लिए प्रायः उपयोग किया जाता है",
            "meta_license_CC0_1.0_description": "(क्रिएटिव कॉमन्स CC0 1.0 - सार्वजनिक डोमेन समर्पण) – कार्य को सार्वजनिक डोमेन में रखता है जिसमें कोई प्रतिबंध नहीं होता; Sketchfab और Thingiverse जैसे रिपॉज़िटरी में 3D मॉडल को स्वतंत्र रूप से साझा करने के लिए आदर्श",
            "meta_license_CC_BY-ND_4.0_description": "(क्रिएटिव कॉमन्स एट्रिब्यूशन-नोडेरिवेटिव्स 4.0) – एट्रिब्यूशन के साथ पुनर्वितरण की अनुमति देता है, लेकिन संशोधन की अनुमति नहीं देता; आधिकारिक या ब्रांड-संवेदनशील 3D सामग्री के लिए उपयोग किया जाता है",
            "meta_license_GPL_v3_description": "(जनरल पब्लिक लाइसेंस v3) – किसी भी व्युत्पन्न कार्य को GPL v3 के तहत ओपन-सोर्स रखना आवश्यक बनाता है, जिससे सभी उपयोगकर्ताओं को स्वतंत्रता मिलती है",
            "meta_license_GPL_v2_description": "(जनरल पब्लिक लाइसेंस v2) – GPL v3 के समान, लेकिन इसमें एंटी-टिवोइज़ेशन खंड शामिल नहीं है; अक्सर पुराने ओपन-सोर्स प्रोजेक्ट्स के लिए उपयोग किया जाता है",
            "meta_license_LGPL_v3_description": "(लेसर जनरल पब्लिक लाइसेंस v3) – स्वामित्व सॉफ़्टवेयर को LGPL-लाइसेंस प्राप्त कोड से जोड़ने की अनुमति देता है, जबकि संशोधनों को ओपन-सोर्स बनाए रखने की आवश्यकता होती है",
            "meta_license_LGPL_v2.1_description": "(लेसर जनरल पब्लिक लाइसेंस v2.1) – LGPL का एक पुराना संस्करण जो स्वामित्व सॉफ़्टवेयर को जोड़ने की अनुमति देता है, लेकिन मुख्य लाइब्रेरी के लिए मुफ्त संशोधन बनाए रखने की आवश्यकता होती है",
            "meta_license_MIT_License_description": "(सबसे सामान्य अनुमतिपूर्ण सॉफ़्टवेयर लाइसेंस, एट्रिब्यूशन आवश्यक) – एट्रिब्यूशन दिए जाने पर उपयोग, संशोधन, और पुनर्वितरण की कोई सीमा नहीं",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (MIT से भी अधिक अनुमतिपूर्ण, कोई एट्रिब्यूशन आवश्यक नहीं) – बिना किसी क्रेडिट के उपयोग, संशोधन और पुनर्वितरण की अनुमति देता है; सरल कोड स्निपेट्स और साझा उपयोगिताओं के लिए उपयोगी",
            "meta_license_Apache_2.0_description": "(MIT के समान लेकिन पेटेंट सुरक्षा शामिल है) – क्रेडिट देने पर स्वतंत्र उपयोग, संशोधन, और पुनर्वितरण की अनुमति देता है, साथ ही पेटेंट दावों के खिलाफ कानूनी सुरक्षा प्रदान करता है",
            "meta_license_BSD_3_description": "(सीमित देयता अस्वीकरण के साथ अनुमतिपूर्ण लाइसेंस) – MIT के समान, लेकिन लेखक के नाम को प्रचार उद्देश्यों के लिए उपयोग करने से स्पष्ट रूप से मना करता है",
            "meta_license_BSD_2_description": "(सरल BSD) (BSD-3 का अधिक अनुमतिपूर्ण रूप) – न्यूनतम प्रतिबंधों के साथ पुनर्वितरण की अनुमति देता है, अक्सर ओपन-सोर्स 3D लाइब्रेरी और उपयोगिताओं में प्रयुक्त होता है",
            "meta_license_BSD_1_description": "(मूल BSD) (सबसे अनुमतिपूर्ण BSD संस्करण, जिसे BSD ज़ीरो भी कहा जाता है) – लगभग कोई प्रतिबंध नहीं; लेकिन आमतौर पर BSD-2 या MIT को प्राथमिकता दी जाती है",
            "meta_license_Standard_Royalty-Free_description": "(सीमित पुनर्वितरण अधिकारों के साथ स्टॉक 3D एसेट्स के लिए सामान्य) – व्यक्तिगत और व्यावसायिक उपयोग की अनुमति देता है लेकिन पुनर्विक्रय या सब-लाइसेंसिंग को निषिद्ध करता है",
            "meta_license_Extended_Commercial_description": "(अधिक अनुमतिपूर्ण व्यावसायिक अधिकार, आमतौर पर एंटरप्राइज़ उपयोग के लिए) – पुनर्विक्रय, सब-लाइसेंसिंग, और व्यापक व्यावसायिक अनुप्रयोगों की अनुमति देता है, आमतौर पर उच्च लागत पर",
            "meta_license_Public_Domain_description": "(स्पष्ट रूप से कार्य को सार्वजनिक डोमेन में रखता है, कोई प्रतिबंध नहीं) – स्वतंत्र रूप से उपयोग, संशोधन और पुनर्वितरण की अनुमति देता है; ऐतिहासिक या सरकारी डेटा पर लागू होता है",
            "meta_license_Unlicense_description": "(सार्वजनिक डोमेन का एक वैकल्पिक संस्करण, मुख्य रूप से सॉफ़्टवेयर के लिए) – पूरी तरह से कॉपीराइट दावों को हटा देता है, जिससे पूर्ण स्वतंत्रता मिलती है",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (मुफ्त उपयोग की अनुमति देता है लेकिन संशोधन को साझा करने की आवश्यकता होती है) – मुख्य रूप से अंतरिक्ष संबंधित डेटासेट और वैज्ञानिक अनुसंधान मॉडलों के लिए उपयोग किया जाता है",
            "meta_license_Mozilla_2.0_description": "(GPL और MIT के बीच एक मध्यम-स्तर का लाइसेंस) – मुफ्त उपयोग और संशोधन की अनुमति देता है, लेकिन संशोधित संस्करणों को वितरित करते समय समान लाइसेंस के तहत साझा करना आवश्यक है",
            "meta_license_Pixar_description": "(Pixar के ओपन-सोर्स प्रोजेक्ट्स जैसे OpenSubdiv के लिए प्रयुक्त) – एट्रिब्यूशन देने पर मुक्त उपयोग और संशोधन की अनुमति देता है, लेकिन सीमित उत्तरदायित्व अस्वीकरण शामिल करता है",
            "meta_license": "लाइसेंस",
            "meta_license_description": "निर्यात की गई फ़ाइल के लिए उपयोग लाइसेंस। इसे मेटाडेटा के रूप में दर्ज किया जाएगा, लेकिन कोई लाइसेंस पाठ प्रति प्रदान नहीं की जाएगी। कस्टम लाइसेंस निर्दिष्ट करने के लिए CUSTOM चुनें और नीचे दिए गए फ़ील्ड में लाइसेंस नाम दर्ज करें",
            "meta_license_custom": "कस्टम लाइसेंस",
            "meta_reference": "संदर्भ",
            "meta_reference_description": "संबंधित संसाधनों या दस्तावेज़ों के लिंक प्रदान करें",
            "meta_keywords": "कीवर्ड",
            "meta_keywords_description": "बेहतर श्रेणीकरण या खोज क्षमता के लिए कीवर्ड सूचीबद्ध करें",
            "meta_description": "विवरण",
            "meta_description_description": "दृश्य या मॉडल का एक संक्षिप्त विवरण प्रदान करें",
            "meta_title": "शीर्षक",
            "meta_title_description": "X3D दृश्य का नाम निर्दिष्ट करें",
            "meta_creator": "निर्माता",
            "meta_creator_description": "फ़ाइल बनाने वाले लेखक या संगठन को निर्दिष्ट करें",
            "label_meta_data": "मेटा डेटा",
        },
        "ar_AR": {
            "import": "استيراد X3D/VRML2",
            "export": "تصدير X3D",
            "file_unit": "وحدة الملف",
            "file_unit_description": "الوحدة المستخدمة في ملف الإدخال",
            "meter": "متر",
            "meter_description": "المتر هو الوحدة الافتراضية لملفات VRML (WRL) و X3D. تفترض معظم البرامج أن الأشياء محددة بالأمتار حسب المواصفات.",
            "decimeter": "ديسيمتر",
            "decimeter_description": "",
            "centimeter": "سنتيمتر",
            "centimeter_description": "",
            "milimeter": "ميليمتر",
            "milimeter_description": "",
            "inch": "بوصة",
            "inch_description": "",
            "custom": "مخصص",
            "custom_description": "استخدم عامل المقياس المحدد أدناه",
            "scale": "المقياس",
            "scale_description": "قيمة المقياس المستخدمة عند تعيين 'وحدة الملف' إلى 'مخصص'",
            "selection_only": "التحديد فقط",
            "selection_only_description": "تصدير الكائنات المحددة فقط",
            "visible_only": "مرئي فقط",
            "visible_only_description": "تصدير الكائنات المرئية فقط",
            "active_collection_only": "مجموعة نشطة فقط",
            "active_collection_only_description": "تصدير الكائنات من المجموعة النشطة فقط",
            "apply_modifiers": "تطبيق المعدلات",
            "apply_modifiers_description": "استخدام بيانات الشبكة المحولة من كل كائن",
            "triangulate": "مثلثي",
            "triangulate_description": "كتابة المربعات في 'IndexedTriangleSet'",
            "normals": "النورمالز",
            "normals_description": "كتابة النورمالز مع الهندسة",
            "compress": "ضغط",
            "compress_description": "ضغط الملف المُصدّر",
            "hierarchy": "التسلسل الهرمي",
            "hierarchy_description": "تصدير علاقات الأب-الابن",
            "name_decorations": "زخرفة الأسماء",
            "name_decorations_description": "إضافة بادئات إلى أسماء العقد المصدرة للإشارة إلى نوعها",
            "h3d_extensions": "امتدادات H3D",
            "h3d_extensions_description": "تصدير شيدر لـ H3D" +
                                          ".\nتحذير: هذه الميزة معطلة للإصدارات من Blender التي تتجاوز 2.79 " +
                                          "نظرًا لإزالة الطريقة المطلوبة من واجهة برمجة التطبيقات لتصدير الشيدرز من Blender." +
                                          "\nقد يتم إصلاح هذه الميزة في المستقبل، ولكن لا يُتوقع دعمها",
            "as_collection": "استيراد كـ مجموعة",
            "as_collection_description": "استيراد الملف كمجموعة جديدة داخل المجموعة النشطة",
            "solidify": "تصلب",
                "solidify_description": "تصلب الكائنات عن طريق إضافة معدل تصلب لكل كائن",
                "solidify_value": "قيمة التصلب",
                "solidify_value_description": "القيمة المستخدمة كعرض لمعدل التصلب",
            "path_mode_name": "وضع المسار",
            "path_mode_description": "الطريقة المستخدمة للإشارة إلى المسارات",
            "relative_mode": "نسبي",
            "relative_mode_description": "دائمًا اكتب المسارات النسبية (عند الإمكان)",
            "strip_mode": "إزالة المسار",
            "strip_mode_description": "اسم الملف فقط",
            "copy_mode": "نسخ",
            "copy_mode_description": "نسخ الملف إلى مسار الوجهة (أو الدليل الفرعي)",
            "label_general": "عام",
            "label_transform": "تحويل",
            "label_mesh": "شبكة",
            "label_include": "تضمين",
            "label_geometry": "هندسة",
            "label_media": "وسائط",
            "batch_off": "إيقاف",
            "batch_off_description": "المشهد النشط إلى ملف",
            "batch_collection": "مجموعة",
            "batch_collection_description": "كل مجموعة كملف",
            "batch_object": "كائن واحد",
            "batch_object_description": "كل كائن كملف",
            "batch_scene": "مشهد",
            "batch_scene_description": "كل مشهد كملف",
            "batch_dir": "دليل خاص",
            "batch_dir_description": "إنشاء دليل لكل ملف تم تصديره",
            "batch_object_hierarchy": "كائن واحد - الحفاظ على العلاقات",
            "batch_object_hierarchy_description": "كل كائن وأطفاله - مع الحفاظ على العلاقات - كملف",
            "meta_license_none": "لا يوجد",
            "meta_license_none_description": "لم يتم توفير ترخيص",
            "meta_license_custom_description": "(ترخيص مخصص لاحتياجات الأعمال المحددة) – يمنح حقوق استخدام معينة بناءً على اتفاق مع مالك المحتوى. يرجى التحديد في الحقل أدناه",
            "meta_license_CC_BY_4.0_description": "(ترخيص المشاع الإبداعي - النسبة 4.0) – يسمح بالاستخدام والتعديل وإعادة التوزيع مجانًا بشرط منح الائتمان؛ يُستخدم غالبًا للأصول ثلاثية الأبعاد المفتوحة والمحتوى التعليمي",
            "meta_license_CC_BY-SA_4.0_description": "(ترخيص المشاع الإبداعي - النسبة والمشاركة بالمثل 4.0) – مشابه لـ CC BY ولكنه يتطلب أن تكون الأعمال المشتقة مرخصة بنفس الشروط؛ يُستخدم عادةً لنماذج ثلاثية الأبعاد مفتوحة المصدر ومجتمعات التصميم المشترك",
            "meta_license_CC_BY-NC_4.0_description": "(ترخيص المشاع الإبداعي - النسبة - غير تجاري 4.0) – يسمح بالتعديل والمشاركة ولكن يحظر الاستخدام التجاري؛ يُستخدم غالبًا للمشاريع الشخصية والأبحاث والتطبيقات غير الربحية",
            "meta_license_CC0_1.0_description": "(ترخيص المشاع الإبداعي CC0 1.0 - التنازل عن الملكية العامة) – يضع العمل في الملكية العامة دون قيود؛ مثالي لمشاركة النماذج ثلاثية الأبعاد بحرية في مستودعات مثل Sketchfab وThingiverse",
            "meta_license_CC_BY-ND_4.0_description": "(ترخيص المشاع الإبداعي - النسبة - عدم الاشتقاق 4.0) – يسمح بإعادة التوزيع مع الإسناد ولكن لا يسمح بالتعديلات؛ يُستخدم للمحتوى ثلاثي الأبعاد الرسمي أو الحساس للعلامة التجارية",
            "meta_license_GPL_v3_description": "(رخصة جنو العامة v3) – يتطلب أن يكون أي عمل مشتق مفتوح المصدر أيضًا بموجب GPL v3، مما يضمن الحرية لجميع المستخدمين",
            "meta_license_GPL_v2_description": "(رخصة جنو العامة v2) – مشابهة لـ GPL v3 ولكنها لا تتضمن بند مكافحة القفل؛ تُستخدم غالبًا للمشاريع مفتوحة المصدر القديمة",
            "meta_license_LGPL_v3_description": "(رخصة جنو العمومية الصغرى v3) – تسمح بربط البرامج الاحتكارية مع كود مرخص بـ LGPL مع ضمان بقاء التعديلات مفتوحة المصدر",
            "meta_license_LGPL_v2.1_description": "(رخصة جنو العمومية الصغرى v2.1) – إصدار أقدم من LGPL يسمح بالربط الاحتكاري مع الاحتفاظ بالتعديلات المجانية للمكتبات الأساسية",
            "meta_license_MIT_License_description": "(الترخيص البرمجي الأكثر شيوعًا والذي يتطلب الإسناد) – يسمح بالاستخدام غير المقيد والتعديل وإعادة التوزيع بشرط منح الإسناد",
            "meta_license_MIT_No_Attribution_description": "(MIT-0) (أكثر تساهلاً من MIT، لا يتطلب إسناد) – يسمح بالاستخدام غير المقيد والتعديل وإعادة التوزيع دون الحاجة إلى منح الائتمان، مفيد لمقتطفات الأكواد والأدوات المشتركة",
            "meta_license_Apache_2.0_description": "(مشابه لـ MIT ولكنه يشمل حماية براءات الاختراع) – يسمح بالاستخدام المجاني والتعديل وإعادة التوزيع مع الإسناد، بالإضافة إلى الحماية القانونية ضد دعاوى براءات الاختراع",
            "meta_license_BSD_3_description": "(رخصة متساهلة مع إخلاء مسؤولية محدود) – مشابهة لـ MIT ولكنها تحظر صراحةً استخدام اسم المؤلف لأغراض الترويج",
            "meta_license_BSD_2_description": "(BSD المبسط) (إصدار أكثر تساهلاً من BSD-3) – يسمح بإعادة التوزيع بقيود قليلة، ويُستخدم عادةً في مكتبات وأدوات ثلاثية الأبعاد مفتوحة المصدر",
            "meta_license_BSD_1_description": "(BSD الأصلي) (أكثر إصدارات BSD تساهلاً، يُعرف أيضًا باسم BSD Zero) – يسمح بالاستخدام المجاني والتعديل مع قيود شبه معدومة، ولكن غالبًا ما يتم استبداله بـ BSD-2 أو MIT",
            "meta_license_Standard_Royalty-Free_description": "(شائع للأصول ثلاثية الأبعاد المخزنة مع حقوق إعادة توزيع محدودة) – يسمح بالاستخدام الشخصي والتجاري ولكنه يحظر إعادة البيع أو الترخيص الفرعي",
            "meta_license_Extended_Commercial_description": "(حقوق تجارية أكثر تساهلاً، غالبًا للاستخدام المؤسسي) – يسمح بإعادة البيع والترخيص الفرعي والتطبيقات التجارية الأوسع، وغالبًا ما يكون بتكلفة أعلى",
            "meta_license_Public_Domain_description": "(يضع العمل في الملكية العامة بشكل صريح، لا قيود على الإطلاق) – يسمح بالاستخدام غير المقيد والتعديل وإعادة التوزيع، ويُطبق غالبًا على البيانات التاريخية أو الحكومية",
            "meta_license_Unlicense_description": "(بديل للملكية العامة، مخصص أساسًا للبرمجيات) – يزيل تمامًا حقوق التأليف والنشر، مما يسمح بحرية الاستخدام الكاملة",
            "meta_license_NOSA_1.3_description": "(NOSA 1.3) (يسمح بالاستخدام المجاني ولكنه يتطلب مشاركة التعديلات) – يُستخدم بشكل أساسي لمجموعات بيانات الفضاء والنماذج البحثية العلمية",
            "meta_license_Mozilla_2.0_description": "(رخصة وسط بين GPL وMIT) – يسمح بالاستخدام والتعديل المجاني، ولكن يجب مشاركة التعديلات تحت نفس الرخصة عند التوزيع",
            "meta_license_Pixar_description": "(يُستخدم لمشاريع بيكسار مفتوحة المصدر مثل OpenSubdiv) – يسمح بالاستخدام والتعديل المجاني مع الإسناد ولكنه يتضمن إخلاء مسؤولية محدود",
            "meta_license": "الترخيص",
            "meta_license_description": "رخصة الاستخدام للملف المُصدر. سيتم تمييزه كبيانات وصفية، ولكن لن يتم توفير نسخة من نص الترخيص. لتحديد ترخيص مخصص، اختر CUSTOM وأدخل اسم الترخيص في الحقل أدناه",
            "meta_license_custom": "ترخيص مخصص",
            "meta_reference": "المرجع",
            "meta_reference_description": "قدم روابط للمصادر أو الوثائق ذات الصلة",
            "meta_keywords": "الكلمات المفتاحية",
            "meta_keywords_description": "قائمة بالكلمات المفتاحية لتحسين التصنيف أو البحث",
            "meta_description": "الوصف",
            "meta_description_description": "قدم وصفًا موجزًا للمشهد أو النموذج",
            "meta_title": "العنوان",
            "meta_title_description": "حدد اسم مشهد X3D",
            "meta_creator": "المُنشئ",
            "meta_creator_description": "حدد المؤلف أو المنظمة التي أنشأت الملف",
            "label_meta_data": "البيانات الوصفية",
        }
    }
